@@ -37,6 +37,7 @@ from virttest import storage
 from virttest import utils_libguestfs
 from virttest import qemu_storage
 from virttest import utils_libvirtd
+from virttest import utils_split_daemons
 from virttest import remote
 from virttest import data_dir
 from virttest import utils_net
@@ -49,8 +50,8 @@ from virttest import utils_package
 from virttest import utils_qemu
 from virttest import migration
 from virttest import utils_kernel_module
+from virttest import arch
 from virttest.utils_version import VersionInterval
-from virttest.compat_52lts import decode_to_text
 from virttest.staging import service
 
 try:
@@ -81,8 +82,8 @@ preprocess_vm_on_hook = None
 postprocess_vm_on_hook = None
 postprocess_vm_off_hook = None
 
-#: Object to handle kvm module reloads with certain parameters
-KVM_MODULE_HANDLER = None
+#: A list to handle kvm and kvm_probe modules reload with certain parameters
+KVM_MODULE_HANDLERS = []
 
 #: QEMU version regex.  Attempts to extract the simple and extended version
 #: information from the output produced by `qemu -version`
@@ -97,8 +98,8 @@ def _get_qemu_version(qemu_cmd):
 
     :param qemu_cmd: Path to qemu binary
     """
-    version_output = decode_to_text(a_process.system_output(
-        "%s -version" % qemu_cmd, verbose=False))
+    version_output = a_process.run("%s -version" % qemu_cmd,
+                                   verbose=False).stdout_text
     version_line = version_output.split('\n')[0]
     matches = re.match(QEMU_VERSION_RE, version_line)
     if matches:
@@ -1171,10 +1172,18 @@ def preprocess(test, params, env):
                     env["cpu_driver"] = cpu_driver[0]
                     params["cpu_driver"] = env.get("cpu_driver")
 
-    kvm_module_params = params.get("kvm_module_parameters", "")
-    force_load = params.get("kvm_module_force_load", "no") == "yes"
-    global KVM_MODULE_HANDLER
-    KVM_MODULE_HANDLER = utils_kernel_module.reload("kvm", force_load, kvm_module_params)
+    global KVM_MODULE_HANDLERS
+    kvm_modules = arch.get_kvm_module_list()
+    for module in reversed(kvm_modules):
+        param_prefix = module if module == "kvm" else "kvm_probe"
+        module_force_load = params.get_boolean("%s_module_force_load"
+                                               % param_prefix)
+        module_parameters = params.get("%s_module_parameters" % param_prefix,
+                                       "")
+        module_handler = utils_kernel_module.reload(module, module_force_load,
+                                                    module_parameters)
+        if module_handler is not None:
+            KVM_MODULE_HANDLERS.append(module_handler)
 
     version_info = {}
     # Get the KVM kernel module version
@@ -1207,8 +1216,8 @@ def preprocess(test, params, env):
 
     if kvm_userspace_ver_cmd:
         try:
-            kvm_userspace_version = decode_to_text(a_process.system_output(
-                kvm_userspace_ver_cmd, shell=True)).strip()
+            kvm_userspace_version = a_process.run(
+                kvm_userspace_ver_cmd, shell=True).stdout_text.strip()
         except a_process.CmdError:
             kvm_userspace_version = "Unknown"
     else:
@@ -1239,8 +1248,8 @@ def preprocess(test, params, env):
     if vm_type == "libvirt":
         libvirt_ver_cmd = params.get("libvirt_ver_cmd", "libvirtd -V|awk -F' ' '{print $3}'")
         try:
-            libvirt_version = decode_to_text(a_process.system_output(
-                libvirt_ver_cmd, shell=True)).strip()
+            libvirt_version = a_process.run(
+                libvirt_ver_cmd, shell=True).stdout_text.strip()
         except a_process.CmdError:
             libvirt_version = "Unknown"
         version_info["libvirt_version"] = str(libvirt_version)
@@ -1286,6 +1295,8 @@ def preprocess(test, params, env):
         # work on connect_uri as default behavior.
         os.environ['LIBVIRT_DEFAULT_URI'] = connect_uri
         if params.get("setup_libvirt_polkit") == "yes":
+            if utils_split_daemons.is_modular_daemon():
+                params.update({"conf_path": "/etc/libvirt/virtqemud.conf"})
             pol = test_setup.LibvirtPolkitConfig(params)
             try:
                 pol.setup()
@@ -1296,7 +1307,7 @@ def preprocess(test, params, env):
             except Exception as e:
                 logging.error("Unexpected error: '%s'" % str(e))
             if libvirtd_inst is None:
-                libvirtd_inst = utils_libvirtd.Libvirtd()
+                libvirtd_inst = utils_libvirtd.Libvirtd("virtqemud")
             libvirtd_inst.restart()
 
     # Execute any pre_commands
@@ -1717,8 +1728,8 @@ def postprocess(test, params, env):
             err += "\nTHP cleanup: %s" % str(details).replace('\\n', '\n  ')
             logging.error(details)
 
-    if KVM_MODULE_HANDLER:
-        KVM_MODULE_HANDLER.restore()
+    for kvm_module in KVM_MODULE_HANDLERS:
+        kvm_module.restore()
 
     if params.get("setup_ksm") == "yes":
         try:
