@@ -9,7 +9,6 @@ import six
 from virttest import xml_utils
 from virttest.libvirt_xml import base, xcepts, accessors
 from virttest.libvirt_xml.devices import librarian
-from virttest.compat_52lts import results_stdout_52lts, results_stderr_52lts
 
 
 class RangeList(list):
@@ -378,7 +377,7 @@ class NetworkXMLBase(base.LibvirtXMLBase):
                  'bandwidth_inbound', 'bandwidth_outbound', 'portgroup',
                  'dns', 'domain_name', 'nat_port', 'forward_interface',
                  'routes', 'virtualport_type', 'vf_list', 'driver', 'pf',
-                 'mtu', 'connection')
+                 'mtu', 'connection', 'port')
 
     __uncompareable__ = base.LibvirtXMLBase.__uncompareable__ + (
         'defined', 'active',
@@ -418,6 +417,8 @@ class NetworkXMLBase(base.LibvirtXMLBase):
         accessors.XMLElementDict('bandwidth_outbound', self,
                                  parent_xpath='/bandwidth',
                                  tag_name='outbound')
+        accessors.XMLElementDict('port', self, parent_xpath='/',
+                                 tag_name='port')
         accessors.XMLAttribute("mtu", self, parent_xpath='/',
                                tag_name='mtu',  attribute='size')
         accessors.XMLAttribute('domain_name', self, parent_xpath='/',
@@ -720,7 +721,7 @@ class NetworkXML(NetworkXMLBase):
         for net_name in networks:
             new_copy = new_netxml.copy()
             dump_result = virsh_instance.net_dumpxml(net_name)
-            new_copy.xml = results_stdout_52lts(dump_result).strip()
+            new_copy.xml = dump_result.stdout_text.strip()
             result[net_name] = new_copy
         return result
 
@@ -735,7 +736,7 @@ class NetworkXML(NetworkXMLBase):
         """
         netxml = NetworkXML(virsh_instance=virsh_instance)
         dump_result = virsh_instance.net_dumpxml(network_name, extra)
-        netxml['xml'] = results_stdout_52lts(dump_result).strip()
+        netxml['xml'] = dump_result.stdout_text.strip()
         return netxml
 
     @staticmethod
@@ -808,7 +809,7 @@ class NetworkXML(NetworkXMLBase):
             raise xcepts.LibvirtXMLError("Failed to undefine network %s.\n"
                                          "Detail: %s" %
                                          (self.name,
-                                          results_stderr_52lts(cmd_result)))
+                                          cmd_result.stderr_text))
 
     def define(self):
         """
@@ -819,7 +820,7 @@ class NetworkXML(NetworkXMLBase):
             raise xcepts.LibvirtXMLError("Failed to define network %s.\n"
                                          "Detail: %s" %
                                          (self.name,
-                                          results_stderr_52lts(cmd_result)))
+                                          cmd_result.stderr_text))
 
     def start(self):
         """
@@ -830,7 +831,7 @@ class NetworkXML(NetworkXMLBase):
             raise xcepts.LibvirtXMLError("Failed to start network %s.\n"
                                          "Detail: %s" %
                                          (self.name,
-                                          results_stderr_52lts(cmd_result)))
+                                          cmd_result.stderr_text))
 
     def sync(self, state=None):
         """
