@@ -19,11 +19,9 @@ from avocado.utils import process
 from virttest import utils_misc
 from virttest import virt_vm
 from virttest import storage
+from virttest import nvme
 from virttest import data_dir
 from virttest import error_context
-from virttest.compat_52lts import (results_stdout_52lts,
-                                   results_stderr_52lts,
-                                   decode_to_text)
 
 
 def filename_to_file_opts(filename):
@@ -95,6 +93,93 @@ def filename_to_file_opts(filename):
                 file_opts.update({'server.{i}.{k}'.format(i=i, k=k): v
                                  for i, server in enumerate(servers)
                                  for k, v in six.iteritems(server)})
+    elif re.match(r'nbd(\+\w+)?://', filename):
+        filename_pattern = re.compile(
+            r'nbd(\+(?:.+))?://((?P<host>[^/:?]+)(:(?P<port>\d+))?)?'
+            r'(/(?P<export>[^?]+))?'
+            r'(\?socket=(?P<socket>.+))?'
+        )
+        matches = filename_pattern.match(filename)
+        if matches:
+            server = {}
+            host = matches.group('host')
+            sock = matches.group('socket')
+
+            if host:
+                # 10890 is the default port for tcp connection
+                port = matches.group('port') if matches.group(
+                                                        'port') else '10809'
+                server = {'server.type': 'inet',
+                          'server.host': host,
+                          'server.port': port}
+            elif sock:
+                server = {'server.type': 'unix', 'server.path': sock}
+
+            if server:
+                # server is required
+                file_opts = {'driver': 'nbd'}
+                file_opts.update(server)
+
+                if matches.group('export'):
+                    file_opts['export'] = matches.group('export')
+    elif filename.startswith('nvme:'):
+        addr, namespace = nvme.parse_uri(filename)
+        file_opts = {'driver': 'nvme', 'device': addr, 'namespace': int(namespace)}
+    elif filename.startswith('ssh:'):
+        filename_pattern = re.compile(
+            r'ssh://((?P<user>.+)@)?(?P<host>[^/:?]+)(:(?P<port>\d+))?'
+            r'(?P<path>/[^?]+)'
+            r'(\?host_key_check=(?P<host_key_check>.+))?'
+        )
+        matches = filename_pattern.match(filename)
+        if matches:
+            matches = matches.groupdict()
+            if matches['host'] is not None and matches['path'] is not None:
+                # required ssh options
+                file_opts = {
+                    'driver': 'ssh',
+                    'server.host': matches['host'],
+                    'server.port': matches['port'] if matches['port'] else 22,
+                    'path': matches['path']
+                }
+
+                if matches['user'] is not None:
+                    file_opts['user'] = matches['user']
+
+                # options in qemu-kvm are different from uri
+                if matches['host_key_check'] is not None:
+                    if matches['host_key_check'] == 'no':
+                        file_opts['host-key-check.mode'] = 'none'
+                    elif matches['host_key_check'] == 'yes':
+                        file_opts['host-key-check.mode'] = 'known_hosts'
+                    else:
+                        m = re.match(r'(?P<type>md5|sha1):(?P<hash>.+)',
+                                     matches['host_key_check']).groupdict()
+                        file_opts.update({
+                            'host-key-check.mode': 'hash',
+                            'host-key-check.type': m['type'],
+                            'host-key-check.hash': m['hash']
+                        })
+    elif re.match(r'(http|https|ftp|ftps)://', filename):
+        filename_pattern = re.compile(
+            r'(?P<protocol>.+?)://((?P<user>.+?)(:(?P<password>.+?))?@)?'
+            r'(?P<server>.+?)/(?P<path>.+)')
+        matches = filename_pattern.match(filename)
+        if matches:
+            matches = matches.groupdict()
+            if all((matches['protocol'], matches['server'], matches['path'])):
+                # required libcurl options, note server can be hostname:port
+                file_opts = {
+                    'driver': matches['protocol'],
+                    'url': '{protocol}://{server}/{path}'.format(
+                        protocol=matches['protocol'],
+                        server=matches['server'],
+                        path=matches['path']
+                    )
+                }
+
+                if matches['user'] is not None:
+                    file_opts['username'] = matches['user']
     # FIXME: Judge the host device by the string starts with "/dev/".
     elif filename.startswith('/dev/'):
         file_opts = {'driver': 'host_device', 'filename': filename}
@@ -158,6 +243,25 @@ def _get_image_meta(image, params, root_dir):
             meta['file'].update({'server.{i}.{k}'.format(i=i+1, k=k): v
                                 for i, server in enumerate(peers)
                                 for k, v in six.iteritems(server)})
+        elif auth_info.storage_type == 'nbd':
+            # qemu-img, as a client, accesses nbd storage
+            if auth_info.tls_creds:
+                meta['file']['tls-creds'] = auth_info.aid
+            if auth_info.reconnect_delay:
+                meta['file']['reconnect-delay'] = auth_info.reconnect_delay
+        elif auth_info.storage_type == 'curl':
+            mapping = {
+                'password-secret': (auth_info.data, auth_info.aid),
+                'sslverify': (auth_info.sslverify, auth_info.sslverify),
+                'cookie-secret': (auth_info.cookie,
+                                  auth_info.cookie.aid
+                                  if auth_info.cookie else ''),
+                'readahead': (auth_info.readahead, auth_info.readahead),
+                'timeout': (auth_info.timeout, auth_info.timeout)
+            }
+            meta['file'].update({
+                k: v[1] for k, v in six.iteritems(mapping) if v[0]
+            })
 
     return meta
 
@@ -222,6 +326,15 @@ def get_image_repr(image, params, root_dir, representation=None):
                 # debug, logfile and other servers represent in json
                 if auth_info.debug or auth_info.logfile or auth_info.peers:
                     access_needed = True
+            elif auth_info.storage_type == 'nbd':
+                # tls-creds, reconnect_delay represent in json
+                access_needed = True
+            elif auth_info.storage_type == 'curl':
+                # u/p can be included in url, while the others should be
+                # represented in json
+                if any((auth_info.sslverify, auth_info.cookie,
+                        auth_info.readahead, auth_info.timeout)):
+                    access_needed = True
 
         func = mapping["json"] if image_secret or access_needed else mapping["filename"]
     return func(image, params, root_dir)
@@ -284,6 +397,7 @@ class QemuImg(storage.QemuImg):
         "unsafe": "-u",
         "options": "-o",
         "secret_object": "",
+        "tls_creds_object": "",
         "image_opts": "",
         "check_repair": "-r",
         "output_format": "--output",
@@ -299,16 +413,19 @@ class QemuImg(storage.QemuImg):
         "compare_strict_mode": "-s",
         "compare_second_image_format": "-F"
         }
-    create_cmd = ("create {secret_object} {image_format} {backing_file} "
-                  "{backing_format} {unsafe!b} {options} {image_filename} "
-                  "{image_size}")
-    check_cmd = ("check {secret_object} {image_opts} {image_format} "
+    create_cmd = ("create {secret_object} {tls_creds_object} {image_format} "
+                  "{backing_file} {backing_format} {unsafe!b} {options} "
+                  "{image_filename} {image_size}")
+    check_cmd = ("check {secret_object} {tls_creds_object} "
+                 "{image_opts} {image_format} "
                  "{output_format} {check_repair} {force_share!b} "
                  "{image_filename}")
-    convert_cmd = ("convert {secret_object} {convert_compressed!b} "
+    convert_cmd = ("convert {secret_object} {tls_creds_object} "
+                   "{convert_compressed!b} {skip_target_image_creation} "
                    "{image_format} {cache_mode} {source_cache_mode} "
                    "{target_image_format} {options} {convert_sparse_size} "
-                   "{image_filename} {target_image_filename}")
+                   "{image_filename} {target_image_filename} "
+                   "{target_image_opts}")
     commit_cmd = ("commit {secret_object} {image_format} {cache_mode} "
                   "{backing_file} {commit_drop!b} {image_filename}")
     resize_cmd = ("resize {secret_object} {image_opts} {resize_shrink!b} "
@@ -316,10 +433,10 @@ class QemuImg(storage.QemuImg):
     rebase_cmd = ("rebase {secret_object} {image_format} {cache_mode} "
                   "{source_cache_mode} {unsafe!b} {backing_file} "
                   "{backing_format} {image_filename}")
-    dd_cmd = ("dd {secret_object} {image_format} {target_image_format} "
-              "{block_size} {count} {skip} "
+    dd_cmd = ("dd {secret_object} {tls_creds_object} {image_format} "
+              "{target_image_format} {block_size} {count} {skip} "
               "if={image_filename} of={target_image_filename}")
-    compare_cmd = ("compare {secret_object} {image_format} "
+    compare_cmd = ("compare {secret_object} {tls_creds_object} {image_format} "
                    "{compare_second_image_format} {source_cache_mode} "
                    "{compare_strict_mode!b} {force_share!b} "
                    "{image_filename} {compare_second_image_filename}")
@@ -336,7 +453,7 @@ class QemuImg(storage.QemuImg):
         self.image_cmd = utils_misc.get_qemu_img_binary(params)
         q_result = process.run(self.image_cmd + ' -h', ignore_status=True,
                                shell=True, verbose=False)
-        self.help_text = results_stdout_52lts(q_result)
+        self.help_text = q_result.stdout_text
         self.cap_force_share = '-U' in self.help_text
         self._cmd_formatter = _ParameterAssembler(self.qemu_img_parameters)
 
@@ -369,12 +486,18 @@ class QemuImg(storage.QemuImg):
                     options.append("%s=%s" % (opt_key.replace("_", "-"),
                                               str(opt_val)))
 
-        access_secret, secret_type = self._image_access_secret
-        if access_secret is not None:
+        if self.data_file:
+            options.extend(
+                ("data_file=%s" % self.data_file.image_filename,
+                 "data_file_raw=%s" % params.get("image_data_file_raw", "off")))
+
+        for access_secret, secret_type in self._image_access_secret:
             if secret_type == 'password':
                 options.append("password-secret=%s" % access_secret.aid)
             elif secret_type == 'key':
                 options.append("key-secret=%s" % access_secret.aid)
+            elif secret_type == 'cookie':
+                options.append("cookie-secret=%s" % access_secret.aid)
 
         image_extra_params = params.get("image_extra_params")
         if image_extra_params:
@@ -410,25 +533,57 @@ class QemuImg(storage.QemuImg):
 
         return needed
 
+    @property
+    def _image_access_tls_creds(self):
+        tls_creds = None
+        creds = self.image_access.image_auth if self.image_access else None
+
+        if creds is not None:
+            if creds.storage_type == 'nbd':
+                if creds.tls_creds:
+                    tls_creds = creds
+
+        return tls_creds
+
+    @property
+    def _backing_access_tls_creds(self):
+        tls_creds_list = []
+        creds_list = self.image_access.image_backing_auth.values() if self.image_access else []
+
+        for creds in creds_list:
+            if creds.storage_type == 'nbd':
+                if creds.tls_creds:
+                    tls_creds_list.append(creds)
+
+        return tls_creds_list
+
     @property
     def _image_access_secret(self):
         """
         Get the access secret object and its type of the image itself,
-        the type can be 'key' or 'password'
+        the type can be 'key' or 'password' or 'cookie'
 
-        :return: a tuple, (StorageAuth object, secret type)
+        :return: a list of tuple(StorageAuth object, secret type) or []
+        :note: an image can have more than one secret objects, e.g.
+               access secret object and cookie secret object for libcurl
         """
-        sec, sec_type = None, None
+        secrets = []
         auth = self.image_access.image_auth if self.image_access else None
 
         if auth is not None:
             if auth.storage_type == 'ceph':
-                # Only ceph image access requires secret object by
+                # ceph image access requires secret object by
                 # qemu-img and only 'password-secret' is supported
                 if auth.data:
-                    sec, sec_type = auth, 'password'
+                    secrets.append((auth, 'password'))
+            elif auth.storage_type == 'curl':
+                # a libcurl image can have more than one secret object
+                if auth.data:
+                    secrets.append((auth, 'password'))
+                if auth.cookie:
+                    secrets.append((auth.cookie, 'cookie'))
 
-        return sec, sec_type
+        return secrets
 
     @property
     def _backing_access_secrets(self):
@@ -443,10 +598,15 @@ class QemuImg(storage.QemuImg):
 
         for auth in info:
             if auth.storage_type == 'ceph':
-                # Only ceph image access requires secret object by
+                # ceph image access requires secret object by
                 # qemu-img and only 'password-secret' is supported
                 if auth.data:
                     secrets.append((auth, 'password'))
+            elif auth.storage_type == 'curl':
+                if auth.data:
+                    secrets.append((auth, 'password'))
+                if auth.cookie:
+                    secrets.append((auth.cookie, 'cookie'))
 
         return secrets
 
@@ -457,20 +617,38 @@ class QemuImg(storage.QemuImg):
         secret_obj_str = "--object secret,id={s.aid},data={s.data}"
         return [secret_obj_str.format(s=s) for s in secret_objects]
 
+    @property
+    def _image_access_tls_creds_object(self):
+        """Get the tls-creds object str of the image itself."""
+        tls_obj_str = '--object tls-creds-x509,id={s.aid},endpoint=client,dir={s.tls_creds}'
+        creds = self._image_access_tls_creds
+        return tls_obj_str.format(s=creds) if creds else ''
+
+    @property
+    def _backing_access_tls_creds_objects(self):
+        """Get all tls-creds object str of the backing images."""
+        tls_creds = []
+        tls_obj_str = '--object tls-creds-x509,id={s.aid},endpoint=client,dir={s.tls_creds}'
+
+        for creds in self._backing_access_tls_creds:
+            tls_creds.append(tls_obj_str.format(s=creds))
+
+        return tls_creds
+
     @property
     def _image_access_secret_object(self):
         """Get the secret object str of the image itself."""
-        secret_obj_str = ''
-        access_secret, secret_type = self._image_access_secret
+        secrets = []
 
-        if access_secret is not None:
+        for access_secret, secret_type in self._image_access_secret:
+            secret_obj_str = ''
             if secret_type == 'password':
-                secret = '--object secret,id={s.aid},format={s.data_format},file={s.filename}'
-            elif secret_type == 'key':
-                secret = '--object secret,id={s.aid},format={s.data_format},data={s.data}'
-            secret_obj_str = secret.format(s=access_secret)
+                secret_obj_str = '--object secret,id={s.aid},format={s.data_format},file={s.filename}'
+            elif secret_type == 'key' or secret_type == 'cookie':
+                secret_obj_str = '--object secret,id={s.aid},format={s.data_format},data={s.data}'
+            secrets.append(secret_obj_str.format(s=access_secret))
 
-        return secret_obj_str
+        return secrets
 
     @property
     def _backing_access_secret_objects(self):
@@ -481,7 +659,7 @@ class QemuImg(storage.QemuImg):
             secret_obj_str = ''
             if secret_type == 'password':
                 secret_obj_str = "--object secret,id={s.aid},format={s.data_format},file={s.filename}"
-            elif secret_type == 'key':
+            elif secret_type == 'key' or secret_type == 'cookie':
                 secret_obj_str = "--object secret,id={s.aid},format={s.data_format},data={s.data}"
             secrets.append(secret_obj_str.format(s=access_secret))
 
@@ -558,7 +736,7 @@ class QemuImg(storage.QemuImg):
 
             # secret object of the image itself
             if self._image_access_secret_object:
-                secret_objects.append(self._image_access_secret_object)
+                secret_objects.extend(self._image_access_secret_object)
 
             image_secret_objects = self._secret_objects
             if image_secret_objects:
@@ -566,6 +744,16 @@ class QemuImg(storage.QemuImg):
             if secret_objects:
                 cmd_dict["secret_object"] = " ".join(secret_objects)
 
+            # tls creds objects of the backing images of the source
+            tls_creds_objects = self._backing_access_tls_creds_objects
+
+            # tls creds object of the source image itself
+            if self._image_access_tls_creds_object:
+                tls_creds_objects.append(self._image_access_tls_creds_object)
+
+            if tls_creds_objects:
+                cmd_dict["tls_creds_object"] = " ".join(tls_creds_objects)
+
             cmd_dict["image_filename"] = self.image_filename
             cmd_dict["image_size"] = self.size
             options = self._parse_options(params)
@@ -602,12 +790,12 @@ class QemuImg(storage.QemuImg):
                                        (self.image_filename, cmd_result))
         if self.encryption_config.key_secret:
             self.encryption_config.key_secret.save_to_file()
-        cmd_result.stdout = results_stdout_52lts(cmd_result)
-        cmd_result.stderr = results_stderr_52lts(cmd_result)
+        cmd_result.stdout = cmd_result.stdout_text
+        cmd_result.stderr = cmd_result.stderr_text
         return self.image_filename, cmd_result
 
     def convert(self, params, root_dir, cache_mode=None,
-                source_cache_mode=None):
+                source_cache_mode=None, skip_target_creation=False):
         """
         Convert image
 
@@ -618,6 +806,9 @@ class QemuImg(storage.QemuImg):
                            (default), ``writethrough``, ``directsync`` and
                            ``unsafe``.
         :param source_cache_mode: the cache mode used with source image file
+        :param skip_target_creation: qemu-img skips the creation of the target
+                                     volume if True(-n), i.e. the target image
+                                     should be created before image convert
         :note: params should contain:
             convert_target
                 the convert target image tag
@@ -643,12 +834,28 @@ class QemuImg(storage.QemuImg):
             "target_image_filename": convert_image.image_filename,
             "cache_mode": cache_mode,
             "source_cache_mode": source_cache_mode,
+            "skip_target_image_creation": "-n" if skip_target_creation else "",
+            "target_image_opts": ""
         }
 
         options = convert_image._parse_options(convert_params)
         if options:
             cmd_dict["options"] = ",".join(options)
 
+        if skip_target_creation:
+            # -o has no effect when skipping image creation
+            # This will become an error in future QEMU versions
+            if options:
+                cmd_dict.pop("options")
+
+            cmd_dict.pop("target_image_format")
+            cmd_dict["target_image_filename"] = ""
+            cmd_dict["target_image_opts"] = ("--target-image-opts '%s'"
+                                             % get_image_opts(
+                                                 convert_image.tag,
+                                                 convert_image.params,
+                                                 convert_image.root_dir))
+
         if (self.encryption_config.key_secret
                 or self._need_auth_info(self.tag)):
             cmd_dict["image_filename"] = "'%s'" % get_image_json(
@@ -664,12 +871,12 @@ class QemuImg(storage.QemuImg):
 
         # secret object of the source image itself
         if self._image_access_secret_object:
-            secret_objects.append(self._image_access_secret_object)
+            secret_objects.extend(self._image_access_secret_object)
 
         # target image access secret object
         # target image to be converted never has backing images
         if convert_image._image_access_secret_object:
-            secret_objects.append(convert_image._image_access_secret_object)
+            secret_objects.extend(convert_image._image_access_secret_object)
 
         # target image secret(luks)
         if convert_image.encryption_config.key_secret:
@@ -678,12 +885,27 @@ class QemuImg(storage.QemuImg):
         if secret_objects:
             cmd_dict["secret_object"] = " ".join(secret_objects)
 
+        # tls creds objects of the backing images of the source
+        tls_creds_objects = self._backing_access_tls_creds_objects
+
+        # tls creds object of the source image itself
+        if self._image_access_tls_creds_object:
+            tls_creds_objects.append(self._image_access_tls_creds_object)
+
+        # tls creds object of the target image
+        if convert_image._image_access_tls_creds_object:
+            tls_creds_objects.append(
+                convert_image._image_access_tls_creds_object)
+
+        if tls_creds_objects:
+            cmd_dict["tls_creds_object"] = " ".join(tls_creds_objects)
+
         convert_cmd = self.image_cmd + " " + \
             self._cmd_formatter.format(self.convert_cmd, **cmd_dict)
 
         logging.info("Convert image %s from %s to %s", self.image_filename,
                      self.image_format, convert_image.image_format)
-        process.system(convert_cmd)
+        process.run(convert_cmd)
         if convert_image.encryption_config.key_secret:
             convert_image.encryption_config.key_secret.save_to_file()
 
@@ -736,7 +958,7 @@ class QemuImg(storage.QemuImg):
                                                       self.base_image_filename))
         rebase_cmd = self.image_cmd + " " + \
             self._cmd_formatter.format(self.rebase_cmd, **cmd_dict)
-        process.system(rebase_cmd)
+        process.run(rebase_cmd)
 
         return self.base_tag
 
@@ -771,7 +993,7 @@ class QemuImg(storage.QemuImg):
         commit_cmd = self.image_cmd + " " + \
             self._cmd_formatter.format(self.commit_cmd, **cmd_dict)
         logging.info("Commit image %s" % self.image_filename)
-        process.system(commit_cmd)
+        process.run(commit_cmd)
 
         return self.image_filename
 
@@ -791,7 +1013,7 @@ class QemuImg(storage.QemuImg):
                                        " parameters")
         cmd += " %s" % self.image_filename
 
-        decode_to_text(process.system_output(cmd))
+        process.run(cmd)
 
         return self.snapshot_tag
 
@@ -816,7 +1038,7 @@ class QemuImg(storage.QemuImg):
         else:
             cmd += " %s" % self.image_filename
 
-        decode_to_text(process.system_output(cmd))
+        process.run(cmd)
 
     def snapshot_list(self):
         """
@@ -825,7 +1047,7 @@ class QemuImg(storage.QemuImg):
         cmd = self.image_cmd
         cmd += " snapshot -l %s" % self.image_filename
 
-        return decode_to_text(process.system_output(cmd))
+        return process.run(cmd).stdout_text
 
     def snapshot_apply(self):
         """
@@ -842,7 +1064,7 @@ class QemuImg(storage.QemuImg):
             raise exceptions.TestError("Can not find the snapshot image"
                                        " parameters")
 
-        decode_to_text(process.system_output(cmd))
+        process.run(cmd)
 
     def remove(self):
         """
@@ -851,6 +1073,12 @@ class QemuImg(storage.QemuImg):
         logging.debug("Removing image file %s", self.image_filename)
         storage.file_remove(self.params, self.image_filename)
 
+        if self.data_file:
+            logging.debug("Removing external data file of image %s",
+                          self.data_file.image_filename)
+            storage.file_remove(self.data_file.params,
+                                self.data_file.image_filename)
+
         secret_files = []
         if self.encryption_config.key_secret:
             secret_files.append(self.encryption_config.key_secret.filename)
@@ -887,13 +1115,21 @@ class QemuImg(storage.QemuImg):
 
         if self._image_access_secret_object:
             # secret object of the image itself
-            cmd += " %s" % self._image_access_secret_object
+            cmd += " %s" % " ".join(self._image_access_secret_object)
+
+        if self._image_access_tls_creds_object:
+            # tls creds object of the image itself
+            cmd += " %s" % self._image_access_tls_creds_object
 
         if backing_chain == "yes":
             if self._backing_access_secret_objects:
                 # secret objects of the backing images
                 cmd += " %s" % " ".join(self._backing_access_secret_objects)
 
+            if self._backing_access_tls_creds_objects:
+                # tls creds objects of the backing images
+                cmd += " %s" % " ".join(self._backing_access_tls_creds_objects)
+
             if "--backing-chain" in self.help_text:
                 cmd += " --backing-chain"
             else:
@@ -909,7 +1145,7 @@ class QemuImg(storage.QemuImg):
                                                      self.root_dir)
         if os.path.exists(image_filename) or self.is_remote_image():
             cmd += " %s --output=%s" % (image_filename, output)
-            output = decode_to_text(process.system_output(cmd, verbose=True))
+            output = process.run(cmd, verbose=True).stdout_text
         else:
             logging.debug("Image file %s not found", image_filename)
             output = None
@@ -972,7 +1208,7 @@ class QemuImg(storage.QemuImg):
 
             if verbose:
                 logging.debug("Output from command: %s",
-                              results_stdout_52lts(cmd_result))
+                              cmd_result.stdout_text)
 
             if cmd_result.exit_status == 0:
                 logging.info("Compared images are equal")
@@ -981,8 +1217,6 @@ class QemuImg(storage.QemuImg):
             else:
                 raise exceptions.TestError("Error in image comparison")
 
-            cmd_result.stdout = results_stdout_52lts(cmd_result)
-            cmd_result.stderr = results_stderr_52lts(cmd_result)
             return cmd_result
 
     def compare_to(self, target_image, source_cache_mode=None,
@@ -1021,7 +1255,7 @@ class QemuImg(storage.QemuImg):
 
         # source image access secret object
         if self._image_access_secret_object:
-            secret_objects.append(self._image_access_secret_object)
+            secret_objects.extend(self._image_access_secret_object)
 
         # target image's backing access secret objects
         if target_image._backing_access_secret_objects:
@@ -1029,13 +1263,33 @@ class QemuImg(storage.QemuImg):
 
         # target image access secret object
         if target_image._image_access_secret_object:
-            secret_objects.append(target_image._image_access_secret_object)
+            secret_objects.extend(target_image._image_access_secret_object)
 
         # if compared images are in the same snapshot chain,
         # needs to remove duplicated secrets
         secret_objects = list(set(secret_objects))
         cmd_dict["secret_object"] = " ".join(secret_objects)
 
+        # tls creds objects of the backing images of the source
+        tls_creds_objects = self._backing_access_tls_creds_objects
+
+        # tls creds object of the source image
+        if self._image_access_tls_creds_object:
+            tls_creds_objects.append(self._image_access_tls_creds_object)
+
+        # tls creds objects of the backing images of the target
+        if target_image._backing_access_tls_creds_objects:
+            tls_creds_objects.extend(
+                target_image._backing_access_tls_creds_objects)
+
+        # tls creds object of the target image
+        if target_image._image_access_tls_creds_object:
+            tls_creds_objects.append(
+                target_image._image_access_tls_creds_object)
+
+        tls_creds_objects = list(set(tls_creds_objects))
+        cmd_dict["tls_creds_object"] = " ".join(tls_creds_objects)
+
         if (self.encryption_config.key_secret
                 or self._need_auth_info(self.tag)):
             cmd_dict["image_filename"] = "'%s'" % \
@@ -1052,7 +1306,7 @@ class QemuImg(storage.QemuImg):
         result = process.run(compare_cmd, ignore_status=True, shell=True)
 
         if verbose:
-            logging.debug("compare output:\n%s", results_stdout_52lts(result))
+            logging.debug("compare output:\n%s", result.stdout_text)
 
         return result
 
@@ -1087,7 +1341,7 @@ class QemuImg(storage.QemuImg):
 
         # access secret object of the image itself
         if self._image_access_secret_object:
-            secret_objects.append(self._image_access_secret_object)
+            secret_objects.extend(self._image_access_secret_object)
 
         # image(e.g. luks image) secret objects
         image_secret_objects = self._secret_objects
@@ -1097,6 +1351,16 @@ class QemuImg(storage.QemuImg):
         if secret_objects:
             cmd_dict["secret_object"] = " ".join(secret_objects)
 
+        # tls creds objects of the backing images
+        tls_creds_objects = self._backing_access_tls_creds_objects
+
+        # tls creds object of the image itself
+        if self._image_access_tls_creds_object:
+            tls_creds_objects.append(self._image_access_tls_creds_object)
+
+        if tls_creds_objects:
+            cmd_dict["tls_creds_object"] = " ".join(tls_creds_objects)
+
         check_cmd = self.image_cmd + " " + self._cmd_formatter.format(
             self.check_cmd, **cmd_dict)
         cmd_result = process.run(check_cmd, ignore_status=True,
@@ -1130,14 +1394,14 @@ class QemuImg(storage.QemuImg):
             except process.CmdError:
                 logging.error("Error getting info from image %s",
                               image_filename)
-            cmd_result = self.check(params, root_dir, force_share=False)
+            cmd_result = self.check(params, root_dir, force_share)
             # Error check, large chances of a non-fatal problem.
             # There are chances that bad data was skipped though
             if cmd_result.exit_status == 1:
-                stdout = results_stdout_52lts(cmd_result)
+                stdout = cmd_result.stdout_text
                 for e_line in stdout.splitlines():
                     logging.error("[stdout] %s", e_line)
-                stderr = results_stderr_52lts(cmd_result)
+                stderr = cmd_result.stderr_text
                 for e_line in stderr.splitlines():
                     logging.error("[stderr] %s", e_line)
                 chk = params.get("backup_image_on_check_error", "no")
@@ -1150,10 +1414,10 @@ class QemuImg(storage.QemuImg):
             # Exit status 2 is data corruption for sure,
             # so fail the test
             elif cmd_result.exit_status == 2:
-                stdout = results_stdout_52lts(cmd_result)
+                stdout = cmd_result.stdout_text
                 for e_line in stdout.splitlines():
                     logging.error("[stdout] %s", e_line)
-                stderr = results_stderr_52lts(cmd_result)
+                stderr = cmd_result.stderr_text
                 for e_line in stderr.splitlines():
                     logging.error("[stderr] %s", e_line)
                 chk = params.get("backup_image_on_check_error", "no")
@@ -1229,8 +1493,6 @@ class QemuImg(storage.QemuImg):
         cmd_list.append("-f %s %s" % (self.image_format, self.image_filename))
         logging.info("Amend image %s" % self.image_filename)
         cmd_result = process.run(" ".join(cmd_list), ignore_status=False)
-        cmd_result.stdout = results_stdout_52lts(cmd_result)
-        cmd_result.stderr = results_stderr_52lts(cmd_result)
         return cmd_result
 
     def resize(self, size, shrink=False, preallocation=None):
@@ -1341,11 +1603,21 @@ class QemuImg(storage.QemuImg):
 
         # access secret object of the image itself
         if self._image_access_secret_object:
-            secret_objects.append(self._image_access_secret_object)
+            secret_objects.extend(self._image_access_secret_object)
 
         if secret_objects:
             cmd_dict["secret_object"] = " ".join(secret_objects)
 
+        # tls creds objects of the backing images
+        tls_creds_objects = self._backing_access_tls_creds_objects
+
+        # tls creds object of the image itself
+        if self._image_access_tls_creds_object:
+            tls_creds_objects.append(self._image_access_tls_creds_object)
+
+        if tls_creds_objects:
+            cmd_dict["tls_creds_object"] = " ".join(tls_creds_objects)
+
         dd_cmd = self.image_cmd + " " + \
             self._cmd_formatter.format(self.dd_cmd, **cmd_dict)
 
