@@ -15,11 +15,10 @@ from avocado.core import exceptions
 from avocado.utils import process
 
 from virttest import data_dir
-from virttest import utils_misc
+from virttest import utils_logfile
 from virttest import rss_client
 from virttest.remote_commander import remote_master
 from virttest.remote_commander import messenger
-from virttest.compat_52lts import results_stdout_52lts, results_stderr_52lts
 
 
 class LoginError(Exception):
@@ -309,8 +308,8 @@ def remote_login(client, host, port, username, password, prompt, linesep="\n",
         session.close()
         raise
     if log_filename:
-        log_file = utils_misc.get_log_filename(log_filename)
-        session.set_output_func(utils_misc.log_line)
+        log_file = utils_logfile.get_log_filename(log_filename)
+        session.set_output_func(utils_logfile.log_line)
         session.set_output_params((log_file,))
         session.set_log_file(os.path.basename(log_file))
     return session
@@ -376,8 +375,8 @@ def remote_commander(client, host, port, username, password, prompt,
         session.close()
         raise
     if log_filename:
-        log_file = utils_misc.get_log_filename(log_filename)
-        session.set_output_func(utils_misc.log_line)
+        log_file = utils_logfile.get_log_filename(log_filename)
+        session.set_output_func(utils_logfile.log_line)
         session.set_output_params((log_file,))
         session.set_log_file(os.path.basename(log_file))
 
@@ -522,7 +521,7 @@ def remote_scp(command, password_list, log_filename=None, transfer_timeout=600,
     logging.debug("Trying to SCP with command '%s', timeout %ss",
                   command, transfer_timeout)
     if log_filename:
-        output_func = utils_misc.log_line
+        output_func = utils_logfile.log_line
         output_params = (log_filename,)
     else:
         output_func = None
@@ -1347,8 +1346,8 @@ class RemoteRunner(object):
                                          (self.stderr_pipe, self.stderr_pipe))
         cmd_result = process.CmdResult(command=command, exit_status=status,
                                        stdout=output, stderr=errput)
-        cmd_result.stdout = results_stdout_52lts(cmd_result)
-        cmd_result.stderr = results_stderr_52lts(cmd_result)
+        cmd_result.stdout = cmd_result.stdout_text
+        cmd_result.stderr = cmd_result.stderr_text
         if status and (not ignore_status):
             raise process.CmdError(command, cmd_result)
         return cmd_result
