@@ -18,15 +18,19 @@ import json
 from avocado.core import exceptions
 from avocado.utils import process
 
+from virttest import storage_ssh
+from virttest import nbd
+from virttest import curl
 from virttest import iscsi
 from virttest import utils_misc
 from virttest import utils_numeric
+from virttest import utils_params
 from virttest import virt_vm
 from virttest import gluster
 from virttest import lvm
 from virttest import ceph
+from virttest import nvme
 from virttest import data_dir
-from virttest.compat_52lts import decode_to_text
 
 
 def preprocess_images(bindir, params, env):
@@ -42,7 +46,7 @@ def preprocess_images(bindir, params, env):
 
 
 def preprocess_image_backend(bindir, params, env):
-    enable_gluster = params.get_boolean("enable_gluster")
+    enable_gluster = params.get("enable_gluster") == "yes"
     gluster_image = params.get("gluster_brick")
     if enable_gluster and gluster_image:
         return gluster.create_gluster_vol(params)
@@ -70,7 +74,7 @@ def file_exists(params, filename_path):
 
     :return: True if image file exists else False
     """
-    if params.get_boolean("enable_gluster"):
+    if params.get("enable_gluster") == "yes":
         return gluster.file_exists(params, filename_path)
 
     if params.get("enable_ceph") == "yes":
@@ -83,6 +87,16 @@ def file_exists(params, filename_path):
         keyring_conf = params.get("image_ceph_keyring_conf")
         return ceph.rbd_image_exist(ceph_monitor, rbd_pool_name,
                                     rbd_image_name, ceph_conf, keyring_conf)
+
+    if params.get('enable_nvme') == 'yes':
+        return nvme.file_exists(params, filename_path)
+
+    if params.get('enable_ssh') == 'yes':
+        return storage_ssh.file_exists(params, filename_path)
+
+    if params.get('enable_curl') == 'yes':
+        return curl.file_exists(params, filename_path)
+
     return os.path.exists(filename_path)
 
 
@@ -153,13 +167,31 @@ def get_image_filename(params, root_dir, basename=False):
            image_format -- the format of the image (qcow2, raw etc)
     :raise VMDeviceError: When no matching disk found (in indirect method).
     """
-    enable_gluster = params.get("enable_gluster", "no") == "yes"
-    enable_ceph = params.get("enable_ceph", "no") == "yes"
-    enable_iscsi = params.get("enable_iscsi", "no") == "yes"
+    enable_ssh = params.get("enable_ssh") == "yes"
+    enable_curl = params.get("enable_curl") == "yes"
+    enable_nbd = params.get("enable_nbd") == "yes"
+    enable_gluster = params.get("enable_gluster") == "yes"
+    enable_ceph = params.get("enable_ceph") == "yes"
+    enable_iscsi = params.get("enable_iscsi") == "yes"
+    enable_nvme = params.get("enable_nvme") == "yes"
     image_name = params.get("image_name")
     storage_type = params.get("storage_type")
     if image_name:
         image_format = params.get("image_format", "qcow2")
+        if enable_curl:
+            # required libcurl params
+            curl_protocol = params['curl_protocol']
+            curl_server = params['curl_server']
+            curl_path = params['curl_path']
+
+            # optional libcurl params
+            curl_user = params.get('curl_username')
+            curl_passwd = params.get('curl_password')
+
+            return curl.get_image_filename(curl_protocol, curl_server,
+                                           curl_path, curl_user, curl_passwd)
+        if enable_nbd:
+            return nbd.get_image_filename(params)
         if enable_iscsi:
             if storage_type == 'iscsi-direct':
                 portal = params.get('portal_ip')
@@ -179,6 +211,22 @@ def get_image_filename(params, root_dir, basename=False):
             ceph_monitor = params.get('ceph_monitor')
             return ceph.get_image_filename(ceph_monitor, rbd_pool_name,
                                            rbd_image_name, ceph_conf)
+        if enable_nvme:
+            address = params['nvme_pci_address']
+            namespace = params.get('nvme_namespace', 1)
+            return nvme.get_image_filename(address, namespace)
+        if enable_ssh:
+            # required libssh options
+            server = params['image_ssh_host']
+            ssh_image_path = params['image_ssh_path']
+
+            # optional libssh options
+            user = params.get('image_ssh_user')
+            port = params.get('image_ssh_port')
+            host_key_check = params.get('image_ssh_host_key_check')
+
+            return storage_ssh.get_image_filename(server, ssh_image_path,
+                                                  user, port, host_key_check)
         return get_image_filename_filesytem(params, root_dir, basename=basename)
     else:
         logging.warn("image_name parameter not set.")
@@ -229,8 +277,8 @@ def get_image_filename_filesytem(params, root_dir, basename=False):
     if indirect_image_select:
         re_name = image_name
         indirect_image_select = int(indirect_image_select)
-        matching_images = decode_to_text(process.system_output("ls -1d %s" % re_name,
-                                                               shell=True))
+        matching_images = process.run("ls -1d %s" % re_name,
+                                      shell=True).stdout_text
         matching_images = sorted(matching_images.split('\n'),
                                  key=functools.cmp_to_key(sort_cmp))
         if matching_images[-1] == '':
@@ -266,6 +314,36 @@ def get_image_filename_filesytem(params, root_dir, basename=False):
     return image_filename
 
 
+def get_iso_filename(cdrom_params, root_dir, basename=False):
+    """
+    Generate an iso image path from params and root_dir.
+
+    :param cdrom_params: Dictionary containing the test parameters.
+    :param root_dir: Base directory for relative iso image.
+    :param basename: True to use only basename of iso image.
+    :return: iso filename
+    """
+    enable_nvme = cdrom_params.get("enable_nvme") == "yes"
+    enable_nbd = cdrom_params.get("enable_nbd") == "yes"
+    enable_gluster = cdrom_params.get("enable_gluster") == "yes"
+    enable_ceph = cdrom_params.get("enable_ceph") == "yes"
+    enable_iscsi = cdrom_params.get("enable_iscsi") == "yes"
+    enable_curl = cdrom_params.get("enable_curl") == "yes"
+    enable_ssh = cdrom_params.get("enable_ssh") == "yes"
+
+    if enable_nvme:
+        return None
+    elif any((enable_nbd, enable_gluster, enable_ceph,
+              enable_iscsi, enable_curl, enable_ssh)):
+        return get_image_filename(cdrom_params, None, basename)
+    else:
+        iso = cdrom_params.get("cdrom")
+        if iso:
+            iso = os.path.basename(iso) if basename else utils_misc.get_path(
+                                                               root_dir, iso)
+        return iso
+
+
 secret_dir = os.path.join(data_dir.get_data_dir(), "images/secrets")
 
 
@@ -309,11 +387,38 @@ class ImageSecret(object):
             fd.write(self.data)
 
 
+class Cookie(object):
+    """
+    Cookie data stored in secret object
+    """
+
+    def __init__(self, image, cookie_data, cookie_data_format):
+        """
+        :param image: image tag name
+        :param cookie_data: cookie data string
+        :param cookie_data_format: raw or base64
+        """
+        self.image = image
+        self.data = cookie_data
+        self.data_format = cookie_data_format
+        self.aid = '%s_cookie_secret' % self.image
+        self.filename = os.path.join(secret_dir, "%s.secret" % self.aid)
+        self.save_to_file()
+
+    def save_to_file(self):
+        """Save secret data to file."""
+        _make_secret_dir()
+        with open(self.filename, "w") as fd:
+            fd.write(self.data)
+
+
 class StorageAuth(object):
     """
     Image storage authentication class.
     iscsi auth: initiator + password
     ceph auth: ceph key
+    nbd auth: tls creds
+    libcurl auth: password sslverify timeout readahead cookie
     """
 
     def __init__(self, image, data, data_format, storage_type, **info):
@@ -321,13 +426,15 @@ class StorageAuth(object):
         :param image: image tag name
         :param data: sensitive data like password
         :param data_format: raw or base64
-        :param storage_type: ceph, glusterfs-direct or iscsi-direct
+        :param storage_type: ceph, glusterfs-direct, iscsi-direct, nbd, curl
         :param info: other access information, such as:
                      iscsi-direct: initiator
                      gluster-direct: debug, logfile, peers
+                     nbd: tls creds path for client access
+                     libcurl: password, sslverify, timeout, readahead, cookie
         """
         self.image = image
-        self.aid = '%s_access_secret' % self.image
+        self.aid = '%s_access' % self.image
         self.storage_type = storage_type
         self.filename = os.path.join(secret_dir, "%s.secret" % self.aid)
         self.data_format = data_format
@@ -344,8 +451,21 @@ class StorageAuth(object):
             # they'll be defined as common options for all backends
             self.debug = info['debug']
             self.logfile = info['logfile']
+        elif self.storage_type == 'nbd':
+            # TODO: now we only support tls-creds-x509, we can add a
+            # param 'nbd_tls_creds_object' to differentiate objects,
+            # e.g. tls-creds-psk
+            self.tls_creds = info['tls_creds']
+            self.reconnect_delay = info['reconnect_delay']
+        elif self.storage_type == 'curl':
+            self._password = data
+            self.cookie = info['cookie']
+            self.sslverify = info['sslverify']
+            self.readahead = info['readahead']
+            self.timeout = info['timeout']
 
         if self.data is not None:
+            self.filename = os.path.join(secret_dir, "%s.secret" % self.aid)
             self.save_to_file()
 
     @property
@@ -354,6 +474,8 @@ class StorageAuth(object):
             return self._chap_passwd
         elif self.storage_type == 'ceph':
             return self._ceph_key
+        elif self.storage_type == 'curl':
+            return self._password
         else:
             return None
 
@@ -371,9 +493,11 @@ class StorageAuth(object):
         """
         auth = None
         storage_type = params.get("storage_type")
-        enable_ceph = params.get("enable_ceph", "no") == "yes"
-        enable_iscsi = params.get("enable_iscsi", "no") == "yes"
-        enable_gluster = params.get("enable_gluster", "no") == "yes"
+        enable_ceph = params.get("enable_ceph") == "yes"
+        enable_iscsi = params.get("enable_iscsi") == "yes"
+        enable_gluster = params.get("enable_gluster") == "yes"
+        enable_nbd = params.get("enable_nbd") == "yes"
+        enable_curl = params.get("enable_curl") == "yes"
 
         if enable_iscsi:
             if storage_type == 'iscsi-direct':
@@ -395,6 +519,43 @@ class StorageAuth(object):
                 auth = cls(image, None, None, storage_type,
                            debug=debug, logfile=logfile,
                            peers=peers) if debug or logfile or peers else None
+        elif enable_nbd:
+            # tls-creds is supported for ip only
+            tls_creds = params.get(
+                'nbd_client_tls_creds') if params.get('nbd_server') else None
+            reconnect_delay = params.get('nbd_reconnect_delay')
+            auth = cls(
+                image, None, None, storage_type,
+                tls_creds=tls_creds, reconnect_delay=reconnect_delay
+            ) if tls_creds or reconnect_delay else None
+        elif enable_curl:
+            # cookie data in a secure way, only for http/https
+            cookie = Cookie(
+                image, params['curl_cookie_secret'],
+                params.get('curl_cookie_secret_format', 'raw'),
+            ) if params.get('curl_cookie_secret') else None
+
+            # sslverify, only for https/ftps
+            sslverify = params.get('curl_sslverify')
+
+            # size of the read-ahead cache
+            readahead = int(float(
+                utils_numeric.normalize_data_size(params['curl_readahead'],
+                                                  order_magnitude="B")
+            )) if params.get('curl_readahead') else None
+
+            # timeout for connections in seconds
+            timeout = params.get('curl_timeout')
+
+            # password
+            data = params.get('curl_password')
+            data_format = params.get('curl_password_format', 'raw')
+
+            if any((data, cookie, sslverify, readahead, timeout)):
+                auth = cls(image, data, data_format, storage_type,
+                           cookie=cookie, sslverify=sslverify,
+                           readahead=readahead, timeout=timeout)
+
         return auth
 
 
@@ -605,8 +766,10 @@ class QemuImg(object):
         self.check_output = params.get("check_output") == "yes"
         self.image_blkdebug_filename = get_image_blkdebug_filename(params,
                                                                    root_dir)
-        self.remote_keywords = params.get("remote_image",
-                                          "gluster iscsi rbd").split()
+        self.remote_keywords = params.get(
+            "remote_image",
+            "gluster iscsi rbd nbd nvme http https ftp ftps"
+        ).split()
         self.encryption_config = ImageEncryption.encryption_define_by_params(
             tag, params)
         image_chain = params.get("image_chain")
@@ -636,6 +799,32 @@ class QemuImg(object):
         self.image_access = ImageAccessInfo.access_info_define_by_params(
                                                    self.tag, self.params)
 
+        self.data_file = self.external_data_file_defined_by_params(
+            params, root_dir, tag)
+
+    @classmethod
+    def external_data_file_defined_by_params(cls, params, root_dir, tag):
+        """Link image to an external data file."""
+        enable_data_file = params.get("enable_data_file", "no") == "yes"
+        image_format = params.get("image_format", "qcow2")
+        if not enable_data_file:
+            return
+        if image_format != "qcow2":
+            raise ValueError("The %s format does not support external "
+                             "data file" % image_format)
+        image_size = params["image_size"]
+        base_name = os.path.basename(params["image_name"])
+        data_file_path = params.get("image_data_file_path",
+                                    os.path.join(root_dir, "images",
+                                                 "%s.data_file"
+                                                 % base_name))
+        data_file_params = utils_params.Params(
+            {"image_name": data_file_path,
+             "image_format": "raw",
+             "image_size": image_size,
+             "image_raw_device": "yes"})
+        return cls(data_file_params, root_dir, "%s_data_file" % tag)
+
     def check_option(self, option):
         """
         Check if object has the option required.
@@ -746,6 +935,11 @@ class QemuImg(object):
             for src, dst in bk_set:
                 self.copy_data_file(src, dst)
 
+        # backup external data file
+        if self.data_file:
+            self.data_file.backup_image(self.data_file.params, root_dir,
+                                        action, good, skip_existing)
+
         for src, dst in backup_set:
             if action == 'backup' and skip_existing and os.path.exists(dst):
                 logging.debug("Image backup %s already exists, skipping...",
@@ -757,6 +951,10 @@ class QemuImg(object):
         """
         Remove backup image
         """
+        # remove external data file backup
+        if self.data_file:
+            self.data_file.rm_backup_image()
+
         backup_dir = utils_misc.get_path(self.root_dir,
                                          self.params.get("backup_dir", ""))
         image_name = os.path.join(backup_dir, "%s.backup" %
