@@ -313,6 +313,19 @@ class LibvirtConfigCommon(SectionlessConfig):
             raise LibvirtConfigUnknownKeyError(key)
 
 
+class LibvirtConfig(LibvirtConfigCommon):
+
+    """
+    Class for libvirt config file.
+    """
+    conf_path = '/etc/libvirt/libvirt.conf'
+    __option_types__ = {
+        'uri_aliases': 'list',
+        'uri_default': 'string',
+        'remote_mode': 'string'
+    }
+
+
 class LibvirtdConfig(LibvirtConfigCommon):
 
     """
@@ -371,6 +384,9 @@ class LibvirtdConfig(LibvirtConfigCommon):
         'admin_keepalive_required': 'int',
         'admin_keepalive_interval': 'int',
         'admin_keepalive_count': 'int',
+        'unix_sock_admin_perms': 'string',
+        'tls_priority': 'tls_priority',
+        'ovs_timeout': 'int',
     }
 
 
@@ -431,6 +447,39 @@ class LibvirtQemuConfig(LibvirtConfigCommon):
         'migration_port_max': 'int',
         'namespaces': 'list',
         'vnc_tls_x509_secret_uuid': 'string',
+        'default_tls_x509_cert_dir': 'string',
+        'default_tls_x509_verify': 'boolean',
+        'default_tls_x509_secret_uuid': 'string',
+        'spice_auto_unix_socket': 'boolean',
+        'spice_sasl': 'boolean',
+        'spice_sasl_dir': 'string',
+        'chardev_tls': 'boolean',
+        'chardev_tls_x509_cert_dir': 'string',
+        'chardev_tls_x509_verify': 'boolean',
+        'chardev_tls_x509_secret_uuid': 'string',
+        'migrate_tls_x509_cert_dir': 'string',
+        'migrate_tls_x509_verify': 'boolean',
+        'migrate_tls_x509_secret_uuid': 'string',
+        'nographics_allow_host_audio': 'boolean',
+        'remember_owner': 'boolean',
+        'pr_helper': 'string',
+        'slirp_helper': 'string',
+        'max_core': 'string',
+        'dump_guest_core': 'boolean',
+        'stdio_handler': 'string',
+        'max_threads_per_process': 'int',
+        'migration_host': 'string',
+        'log_timestamp': 'boolean',
+        'nvram': 'list',
+        'gluster_debug_level': 'int',
+        'memory_backing_dir': 'string',
+        'vxhs_tls': 'boolean',
+        'vxhs_tls_x509_cert_dir': 'string',
+        'nbd_tls': 'boolean',
+        'nbd_tls_x509_cert_dir': 'string',
+        'swtpm_user': 'string',
+        'swtpm_group': 'string',
+        'capability_filters': 'list',
     }
 
 
@@ -676,3 +725,27 @@ class VirtProxydConfig(VirtQemudConfig):
 
         'ovs_timeout': 'int',
     }
+
+
+def get_conf_obj(config_type):
+    """
+    Wrapper method to get the object from the given configuration type
+
+    :param config_type: The configuration type to get
+        For example, "libvirtd" or "virtqemud"
+    :return: utils_config.LibvirtConfigCommon object
+    """
+    return {
+        'libvirt': LibvirtConfig,
+        'libvirtd': LibvirtdConfig,
+        'qemu': LibvirtQemuConfig,
+        'sysconfig': LibvirtdSysConfig,
+        'guestconfig': LibvirtGuestsConfig,
+        'virtqemud': VirtQemudConfig,
+        'virtproxyd': VirtProxydConfig,
+        'virtnetworkd': VirtNetworkdConfig,
+        'virtstoraged': VirtStoragedConfig,
+        'virtinterfaced': VirtInterfacedConfig,
+        'virtnodedevd': VirtNodedevdConfig,
+        'virtnwfilterd': VirtNwfilterdConfig
+         }.get(config_type)()
