@@ -15,7 +15,7 @@ from virttest import propcan, remote, utils_libvirtd
 from virttest import data_dir
 from virttest import utils_package
 from virttest import libvirt_version
-from virttest.compat_52lts import results_stderr_52lts
+from virttest import utils_split_daemons
 
 
 class ConnectionError(Exception):
@@ -666,7 +666,8 @@ class TCPConnection(ConnectionBase):
     __slots__ = ('tcp_port', 'remote_syslibvirtd', 'sasl_type',
                  'remote_libvirtdconf', 'sasl_allowed_users',
                  'auth_tcp', 'listen_addr', 'remote_saslconf',
-                 'remote_libvirtd_tcp_socket')
+                 'remote_libvirtd_tcp_socket', 'client_hosts',
+                 'daemon_conf', 'daemon_socket_conf')
 
     def __init__(self, *args, **dargs):
         """
@@ -686,6 +687,13 @@ class TCPConnection(ConnectionBase):
         init_dict['sasl_allowed_users'] = init_dict.get('sasl_allowed_users')
         super(TCPConnection, self).__init__(init_dict)
 
+        if utils_split_daemons.is_modular_daemon():
+            self.daemon_conf = "/etc/libvirt/virtproxyd.conf"
+            self.daemon_socket_conf = "/usr/lib/systemd/system/virtproxyd-tcp.socket"
+        else:
+            self.daemon_conf = "/etc/libvirt/libvirtd.conf"
+            self.daemon_socket_conf = "/usr/lib/systemd/system/libvirtd-tcp.socket"
+
         self.remote_syslibvirtd = remote.RemoteFile(
             address=self.server_ip,
             client='scp',
@@ -700,7 +708,7 @@ class TCPConnection(ConnectionBase):
             username=self.server_user,
             password=self.server_pwd,
             port='22',
-            remote_path='/etc/libvirt/libvirtd.conf')
+            remote_path=self.daemon_conf)
 
         self.remote_libvirtd_tcp_socket = remote.RemoteFile(
             address=self.server_ip,
@@ -708,7 +716,7 @@ class TCPConnection(ConnectionBase):
             username=self.server_user,
             password=self.server_pwd,
             port='22',
-            remote_path='/usr/lib/systemd/system/libvirtd-tcp.socket')
+            remote_path=self.daemon_socket_conf)
 
         self.remote_saslconf = remote.RemoteFile(
             address=self.server_ip,
@@ -718,6 +726,14 @@ class TCPConnection(ConnectionBase):
             port='22',
             remote_path='/etc/sasl2/libvirt.conf')
 
+        self.client_hosts = remote.RemoteFile(
+            address=self.client_ip,
+            client='scp',
+            username=self.client_user,
+            password=self.client_pwd,
+            port='22',
+            remote_path='/etc/hosts')
+
     def conn_recover(self):
         """
         Clean up for TCP connection.
@@ -735,17 +751,19 @@ class TCPConnection(ConnectionBase):
         del self.remote_libvirtdconf
         del self.remote_saslconf
         del self.remote_libvirtd_tcp_socket
+        del self.client_hosts
 
         # restart libvirtd service on server
         try:
             session = remote.wait_for_login('ssh', server_ip, '22',
                                             server_user, server_pwd,
                                             r"[\#\$]\s*$")
-            libvirtd_service = utils_libvirtd.Libvirtd(session=session)
             if libvirt_version.version_compare(5, 6, 0, session):
-                session.cmd("systemctl stop libvirtd-tcp.socket")
-                libvirtd_service.start()
+                tcp_socket_service = utils_libvirtd.DaemonSocket(
+                    "virtproxyd-tcp.socket", session=session)
+                tcp_socket_service.stop()
             else:
+                libvirtd_service = utils_libvirtd.Libvirtd(session=session)
                 libvirtd_service.restart()
         except (remote.LoginError, aexpect.ShellError) as detail:
             raise ConnServerRestartError(detail)
@@ -788,8 +806,7 @@ class TCPConnection(ConnectionBase):
                                r".*tcp_port\s*=.*": 'tcp_port="%s"' % (tcp_port),
                                r".*auth_tcp\s*=.*": 'auth_tcp="%s"' % (auth_tcp)}
         else:
-            # After libvirt 5.6.0, auth_tcp must be set to 'none'
-            pattern_to_repl = {r".*auth_tcp\s*=.*": 'auth_tcp="none"'}
+            pattern_to_repl = {r".*auth_tcp\s*=.*": 'auth_tcp="%s"' % (auth_tcp)}
         # a whitelist of allowed SASL usernames, it's a list.
         # If the list is an empty, no client can connect
         if sasl_allowed_users:
@@ -801,8 +818,14 @@ class TCPConnection(ConnectionBase):
         self.remote_libvirtdconf.sub_else_add(pattern_to_repl)
 
         # edit the /etc/sasl2/libvirt.conf to change sasl method
+        # edit the /etc/hosts to add the host
         if self.sasl_type == 'gssapi':
             keytab = "keytab: /etc/libvirt/krb5.tab"
+            if listen_addr:
+                server_runner = remote.RemoteRunner(session=server_session)
+                hostname = server_runner.run('hostname', ignore_status=True).stdout_text.strip()
+                pattern_to_repl = {r".*%s.*" % listen_addr: "%s %s" % (listen_addr, hostname)}
+                self.client_hosts.sub_else_add(pattern_to_repl)
         else:
             keytab = ""
         pattern_to_repl = {r".*mech_list\s*:\s*.*":
@@ -821,16 +844,17 @@ class TCPConnection(ConnectionBase):
                                             r"[\#\$]\s*$")
             remote_runner = remote.RemoteRunner(session=session)
             remote_runner.run('iptables -F', ignore_status=True)
-            libvirtd_service = utils_libvirtd.Libvirtd(session=session)
             # From libvirt 5.6, libvirtd is using systemd socket activation
             # by default
             if libvirt_version.version_compare(5, 6, 0, session):
                 # Before start libvirtd-tcp.socket, user must stop libvirtd.
                 # After libvirtd-tcp.socket is started, user mustn't start
                 # libvirtd.
-                libvirtd_service.stop()
-                session.cmd("systemctl restart libvirtd-tcp.socket")
+                tcp_socket_service = utils_libvirtd.DaemonSocket(
+                    "virtproxyd-tcp.socket", session=session)
+                tcp_socket_service.restart()
             else:
+                libvirtd_service = utils_libvirtd.Libvirtd(session=session)
                 libvirtd_service.restart()
         except (remote.LoginError, aexpect.ShellError) as detail:
             raise ConnServerRestartError(detail)
@@ -862,6 +886,8 @@ class TLSConnection(ConnectionBase):
     credential_dict: A dict for required file names in libvirt or qemu style
     qemu_tls: True for qemu native TLS support
     qemu_chardev_tls: True for config chardev tls in qemu conf
+    special_cn: Use special cn in /etc/hosts, default don't use
+    server_setup_local: Whether to setup tls server on local host
     """
     __slots__ = ('server_cn', 'client_cn', 'ca_cn', 'CERTTOOL', 'pki_CA_dir',
                  'libvirt_pki_dir', 'libvirt_pki_private_dir', 'client_hosts',
@@ -872,7 +898,9 @@ class TLSConnection(ConnectionBase):
                  'client_libvirtdconf', 'client_syslibvirtd', 'server_hosts',
                  'credential_dict', 'qemu_tls', 'qemu_chardev_tls',
                  'server_saslconf', 'server_qemuconf', 'client_qemuconf',
-                 'server_libvirtd_tls_socket', 'client_libvirtd_tls_socket')
+                 'server_libvirtd_tls_socket', 'client_libvirtd_tls_socket',
+                 'special_cn', 'server_setup_local',
+                 'daemon_conf', 'daemon_socket_conf')
 
     def __init__(self, *args, **dargs):
         """
@@ -887,18 +915,20 @@ class TLSConnection(ConnectionBase):
         init_dict['server_cn'] = init_dict.get('server_cn', 'TLSServer')
         init_dict['client_cn'] = init_dict.get('client_cn', 'TLSClient')
         init_dict['ca_cn'] = init_dict.get('ca_cn', 'AUTOTEST.VIRT')
-        init_dict['ca_cakey_path'] = init_dict.get('ca_cakey_path', None)
         init_dict['auth_tls'] = init_dict.get('auth_tls', 'none')
         init_dict['tls_port'] = init_dict.get('tls_port', '16514')
         init_dict['listen_addr'] = init_dict.get('listen_addr')
         init_dict['custom_pki_path'] = init_dict.get('custom_pki_path')
         init_dict['tls_verify_cert'] = init_dict.get('tls_verify_cert', 'yes')
         init_dict['tls_sanity_cert'] = init_dict.get('tls_sanity_cert', 'yes')
+        init_dict['ca_cakey_path'] = init_dict.get('ca_cakey_path', None)
         init_dict['tls_allowed_dn_list'] = init_dict.get('tls_allowed_dn_list')
         init_dict['scp_new_cacert'] = init_dict.get('scp_new_cacert', 'yes')
         init_dict['sasl_type'] = init_dict.get('sasl_type', 'gssapi')
         init_dict['restart_libvirtd'] = init_dict.get(
             'restart_libvirtd', 'yes')
+        init_dict['special_cn'] = init_dict.get('special_cn', 'no')
+        init_dict['server_setup_local'] = init_dict.get('server_setup_local', False)
 
         super(TLSConnection, self).__init__(init_dict)
         # check and set CERTTOOL in slots
@@ -921,7 +951,8 @@ class TLSConnection(ConnectionBase):
                                 'servercert': 'server%scert.pem' % delimeter,
                                 'serverkey': 'server%skey.pem' % delimeter,
                                 'clientcert': 'client%scert.pem' % delimeter,
-                                'clientkey': 'client%skey.pem' % delimeter}
+                                'clientkey': 'client%skey.pem' % delimeter,
+                                'ca_cakey_path': self.ca_cakey_path}
         # set some pki related dir values
         if not self.custom_pki_path:
             self.pki_CA_dir = ('/etc/pki/CA/')
@@ -977,13 +1008,20 @@ class TLSConnection(ConnectionBase):
             port='22',
             remote_path='/etc/sysconfig/libvirtd')
 
+        if utils_split_daemons.is_modular_daemon():
+            self.daemon_conf = "/etc/libvirt/virtproxyd.conf"
+            self.daemon_socket_conf = "/usr/lib/systemd/system/virtproxyd-tls.socket"
+        else:
+            self.daemon_conf = "/etc/libvirt/libvirtd.conf"
+            self.daemon_socket_conf = "/usr/lib/systemd/system/libvirtd-tls.socket"
+
         self.server_libvirtdconf = remote.RemoteFile(
             address=self.server_ip,
             client='scp',
             username=self.server_user,
             password=self.server_pwd,
             port='22',
-            remote_path='/etc/libvirt/libvirtd.conf')
+            remote_path=self.daemon_conf)
 
         self.server_saslconf = remote.RemoteFile(
             address=self.server_ip,
@@ -1007,7 +1045,7 @@ class TLSConnection(ConnectionBase):
             username=self.client_user,
             password=self.client_pwd,
             port='22',
-            remote_path='/etc/libvirt/libvirtd.conf')
+            remote_path=self.daemon_conf)
 
         self.client_libvirtd_tls_socket = remote.RemoteFile(
             address=self.client_ip,
@@ -1015,7 +1053,7 @@ class TLSConnection(ConnectionBase):
             username=self.client_user,
             password=self.client_pwd,
             port='22',
-            remote_path='/usr/lib/systemd/system/libvirtd-tls.socket')
+            remote_path=self.daemon_socket_conf)
 
         self.server_libvirtd_tls_socket = remote.RemoteFile(
             address=self.server_ip,
@@ -1023,7 +1061,7 @@ class TLSConnection(ConnectionBase):
             username=self.server_user,
             password=self.server_pwd,
             port='22',
-            remote_path='/usr/lib/systemd/system/libvirtd-tls.socket')
+            remote_path=self.daemon_socket_conf)
 
     def conn_recover(self):
         """
@@ -1056,14 +1094,21 @@ class TLSConnection(ConnectionBase):
 
         # restart libvirtd service on server
         try:
+            if self.server_setup_local:
+                libvirtd_service = utils_libvirtd.Libvirtd()
+                if libvirt_version.version_compare(5, 6, 0):
+                    process.run("systemctl stop libvirtd-tls.socket")
+                libvirtd_service.restart()
+
             session = remote.wait_for_login('ssh', server_ip, '22',
                                             server_user, server_pwd,
                                             r"[\#\$]\s*$")
-            libvirtd_service = utils_libvirtd.Libvirtd(session=session)
             if libvirt_version.version_compare(5, 6, 0, session):
-                session.cmd("systemctl stop libvirtd-tls.socket")
-                libvirtd_service.start()
+                tls_socket_service = utils_libvirtd.DaemonSocket(
+                    "virtproxyd-tls.socket", session=session)
+                tls_socket_service.stop()
             else:
+                libvirtd_service = utils_libvirtd.Libvirtd(session=session)
                 libvirtd_service.restart()
         except (remote.LoginError, aexpect.ShellError) as detail:
             raise ConnServerRestartError(detail)
@@ -1110,8 +1155,7 @@ class TLSConnection(ConnectionBase):
         server_session.close()
         logging.debug("TLS certifications recover successfully.")
 
-    def conn_setup(self, server_setup=True, client_setup=True,
-                   server_setup_local=False):
+    def conn_setup(self, server_setup=True, client_setup=True):
         """
         setup a TLS connection between server and client.
         At first check the certtool needed to setup.
@@ -1121,8 +1165,6 @@ class TLSConnection(ConnectionBase):
                              False to not setup
         :param client_setup: True to setup TLS client on source host,
                              False to not setup
-        :param server_setup_local: True to setup TLS server on source host,
-                             False to not setup
         """
         if self.CERTTOOL == '/bin/true':
             raise ConnToolNotFoundError('certtool',
@@ -1130,14 +1172,13 @@ class TLSConnection(ConnectionBase):
 
         # support build multiple CAs with different CA CN
         build_CA(self.tmp_dir, self.ca_cn,
-                 self.ca_cakey_path, self.CERTTOOL,
-                 self.credential_dict)
+                 self.CERTTOOL, self.credential_dict)
         # not always need to setup CA, client and server together
         if server_setup:
             self.server_setup()
         if client_setup:
             self.client_setup()
-        if server_setup_local:
+        if self.server_setup_local:
             self.server_setup(on_local=True)
 
         self.close_session()
@@ -1161,7 +1202,7 @@ class TLSConnection(ConnectionBase):
         tmp_dir = self.tmp_dir
         scp_new_cacert = self.scp_new_cacert
         # sometimes, need to reuse previous CA cert
-        if self.ca_cakey_path and scp_new_cacert == 'no':
+        if self.ca_cakey_path:
             cacert_path = os.path.join(self.ca_cakey_path, self.credential_dict['cacert'])
             cakey_path = os.path.join(self.ca_cakey_path, self.credential_dict['cakey'])
         else:
@@ -1194,8 +1235,7 @@ class TLSConnection(ConnectionBase):
         tls_sanity_cert = self.tls_sanity_cert
 
         # build a server key.
-        build_server_key(tmp_dir, self.ca_cakey_path,
-                         server_cn, self.CERTTOOL,
+        build_server_key(tmp_dir, server_cn, server_ip, self.CERTTOOL,
                          self.credential_dict, on_local)
 
         # scp cacert.pem, servercert.pem and serverkey.pem to server.
@@ -1210,10 +1250,14 @@ class TLSConnection(ConnectionBase):
         if status:
             raise ConnMkdirError(self.libvirt_pki_private_dir, output)
 
-        scp_dict = {cacert_path: self.pki_CA_dir,
-                    cakey_path: self.pki_CA_dir,
-                    servercert_path: self.libvirt_pki_dir,
-                    serverkey_path: self.libvirt_pki_private_dir}
+        if scp_new_cacert == 'no':
+            scp_dict = {servercert_path: self.libvirt_pki_dir,
+                        serverkey_path: self.libvirt_pki_private_dir}
+        else:
+            scp_dict = {cacert_path: self.pki_CA_dir,
+                        cakey_path: self.pki_CA_dir,
+                        servercert_path: self.libvirt_pki_dir,
+                        serverkey_path: self.libvirt_pki_private_dir}
 
         for key in scp_dict:
             local_path = key
@@ -1247,9 +1291,8 @@ class TLSConnection(ConnectionBase):
                             "chardev_tls = 1"}
             operate_qemuconf.sub_else_add(pattern2repl)
             pattern2repl = {r".*chardev_tls_x509_cert_dir\s*="
-                            "\s*\"\/etc\/pki\/libvirt-chardev\s*\".*":
-                            "chardev_tls_x509_cert_dir="
-                            "\"/etc/pki/libvirt-chardev\""}
+                            r"\s*\"\/etc\/pki\/libvirt-chardev\s*\".*":
+                            "chardev_tls_x509_cert_dir = \"/etc/pki/libvirt-chardev\""}
             operate_qemuconf.sub_else_add(pattern2repl)
 
         if not libvirt_version.version_compare(5, 6, 0, server_session):
@@ -1336,29 +1379,27 @@ class TLSConnection(ConnectionBase):
         # restart libvirtd service on server
         if restart_libvirtd == "yes":
             if on_local:
-                libvirtd_service = utils_libvirtd.Libvirtd()
                 # From libvirt 5.6, libvirtd is using systemd socket activation
                 # by default
                 if libvirt_version.version_compare(5, 6, 0):
-                    process.run("systemctl stop libvirtd.socket")
-                    libvirtd_service.stop()
-                    process.run("systemctl start libvirtd.socket")
-                    process.run("systemctl restart libvirtd-tls.socket")
-                    libvirtd_service.start()
+                    tls_socket_service = utils_libvirtd.DaemonSocket(
+                        "virtproxyd-tls.socket")
+                    tls_socket_service.restart()
                 else:
+                    libvirtd_service = utils_libvirtd.Libvirtd()
                     libvirtd_service.restart()
             else:
                 try:
                     session = remote.wait_for_login('ssh', server_ip, '22',
                                                     server_user, server_pwd,
                                                     r"[\#\$]\s*$")
-                    remote_runner = remote.RemoteRunner(session=session)
-                    remote_runner.run('iptables -F', ignore_status=True)
-                    libvirtd_service = utils_libvirtd.Libvirtd(session=session)
                     if libvirt_version.version_compare(5, 6, 0, session):
-                        libvirtd_service.stop()
-                        session.cmd("systemctl restart libvirtd-tls.socket")
+                        tls_socket_service = utils_libvirtd.DaemonSocket(
+                            "virtproxyd-tls.socket", session=session)
+                        tls_socket_service.restart()
                     else:
+                        libvirtd_service = utils_libvirtd.Libvirtd(
+                            session=session)
                         libvirtd_service.restart()
                 except (remote.LoginError, aexpect.ShellError) as detail:
                     raise ConnServerRestartError(detail)
@@ -1366,8 +1407,10 @@ class TLSConnection(ConnectionBase):
         # edit /etc/hosts on remote host in case of connecting
         # from remote host to local host
         if not on_local:
-            pattern_to_repl = {r".*%s.*" % self.client_cn:
-                               "%s %s" % (self.client_ip, self.client_cn)}
+            client_runner = remote.RemoteRunner(session=self.client_session)
+            hostname = client_runner.run('hostname', ignore_status=True).stdout_text.strip()
+            pattern_to_repl = {r".*%s.*" % self.client_ip:
+                               "%s %s" % (self.client_ip, hostname)}
             self.server_hosts.sub_else_add(pattern_to_repl)
 
     def client_setup(self):
@@ -1381,9 +1424,15 @@ class TLSConnection(ConnectionBase):
         """
         # initialize variables
         tmp_dir = self.tmp_dir
+        scp_new_cacert = self.scp_new_cacert
+        # sometimes, need to reuse previous CA cert
+        if self.ca_cakey_path and scp_new_cacert == 'no':
+            cacert_path = os.path.join(self.ca_cakey_path, self.credential_dict['cacert'])
+            cakey_path = os.path.join(self.ca_cakey_path, self.credential_dict['cakey'])
+        else:
+            cacert_path = os.path.join(tmp_dir, self.credential_dict['cacert'])
+            cakey_path = os.path.join(tmp_dir, self.credential_dict['cakey'])
 
-        cacert_path = os.path.join(tmp_dir, self.credential_dict['cacert'])
-        cakey_path = os.path.join(tmp_dir, self.credential_dict['cakey'])
         clientkey_path = os.path.join(tmp_dir, self.credential_dict['clientkey'])
         clientcert_path = os.path.join(tmp_dir, self.credential_dict['clientcert'])
 
@@ -1406,10 +1455,14 @@ class TLSConnection(ConnectionBase):
                 if status:
                     raise ConnMkdirError(target_dir, output)
 
-        scp_dict = {cacert_path: self.pki_CA_dir,
-                    cakey_path: self.pki_CA_dir,
-                    clientcert_path: self.libvirt_pki_dir,
-                    clientkey_path: self.libvirt_pki_private_dir}
+        if scp_new_cacert == 'no':
+            scp_dict = {clientcert_path: self.libvirt_pki_dir,
+                        clientkey_path: self.libvirt_pki_private_dir}
+        else:
+            scp_dict = {cacert_path: self.pki_CA_dir,
+                        cakey_path: self.pki_CA_dir,
+                        clientcert_path: self.libvirt_pki_dir,
+                        clientkey_path: self.libvirt_pki_private_dir}
 
         for key in scp_dict:
             local_path = key
@@ -1422,8 +1475,14 @@ class TLSConnection(ConnectionBase):
                                    client_ip, remote_path, detail)
 
         # edit /etc/hosts on client
-        pattern_to_repl = {r".*%s.*" % self.server_cn:
-                           "%s %s" % (self.server_ip, self.server_cn)}
+        server_runner = remote.RemoteRunner(session=self.server_session)
+        hostname = server_runner.run('hostname', ignore_status=True).stdout_text.strip()
+        if self.special_cn == "yes":
+            pattern_to_repl = {r".*%s.*" % self.server_ip:
+                               "%s %s" % (self.server_ip, self.server_cn)}
+        else:
+            pattern_to_repl = {r".*%s.*" % self.server_ip:
+                               "%s %s" % (self.server_ip, hostname)}
         self.client_hosts.sub_else_add(pattern_to_repl)
 
 
@@ -1440,9 +1499,14 @@ def build_client_key(tmp_dir, client_cn="TLSClient", certtool="certtool",
     :param credential_dict: A dict for credential files' names
     """
     # Initialize variables
-
-    cakey_path = os.path.join(tmp_dir, credential_dict['cakey'])
-    cacert_path = os.path.join(tmp_dir, credential_dict['cacert'])
+    # sometimes, need to reuse previous CA cert
+    ca_cakey_path = credential_dict.get('ca_cakey_path', None)
+    if not ca_cakey_path:
+        cakey_path = os.path.join(tmp_dir, credential_dict['cakey'])
+        cacert_path = os.path.join(tmp_dir, credential_dict['cacert'])
+    else:
+        cakey_path = os.path.join(ca_cakey_path, credential_dict['cakey'])
+        cacert_path = os.path.join(ca_cakey_path, credential_dict['cacert'])
     clientkey_path = os.path.join(tmp_dir, credential_dict['clientkey'])
     clientcert_path = os.path.join(tmp_dir, credential_dict['clientcert'])
     clientinfo_path = os.path.join(tmp_dir, 'client.info')
@@ -1451,7 +1515,7 @@ def build_client_key(tmp_dir, client_cn="TLSClient", certtool="certtool",
     cmd = "%s --generate-privkey > %s" % (certtool, clientkey_path)
     CmdResult = process.run(cmd, ignore_status=True, shell=True)
     if CmdResult.exit_status:
-        raise ConnPrivKeyError(clientkey_path, results_stderr_52lts(CmdResult))
+        raise ConnPrivKeyError(clientkey_path, CmdResult.stderr_text)
 
     # prepare a info file to build clientcert.
     clientinfo_file = open(clientinfo_path, "w")
@@ -1470,25 +1534,26 @@ def build_client_key(tmp_dir, client_cn="TLSClient", certtool="certtool",
             cakey_path, clientinfo_path, clientcert_path))
     CmdResult = process.run(cmd, ignore_status=True)
     if CmdResult.exit_status:
-        raise ConnCertError(clientinfo_path, results_stderr_52lts(CmdResult))
+        raise ConnCertError(clientinfo_path, CmdResult.stderr_text)
 
 
-def build_server_key(tmp_dir, ca_cakey_path=None,
-                     server_cn="TLSServer", certtool="certtool",
-                     credential_dict=None, on_local=False):
+def build_server_key(tmp_dir, server_cn="TLSServer", server_ip="SERVER.IP",
+                     certtool="certtool", credential_dict=None,
+                     on_local=False):
     """
     (1).initialization for variables.
     (2).make a private key with certtool command.
     (3).prepare a info file.
     (4).make a certificate file with certtool command.
 
-    :param client_cn: cn for client info
+    :param server_cn: cn for server info
     :param certtool: cert command
     :param credential_dict: A dict for credential files' names
     :param on_local: True to clean up old server key on source host
     """
     # initialize variables
     # sometimes, need to reuse previous CA cert
+    ca_cakey_path = credential_dict.get('ca_cakey_path', None)
     if not ca_cakey_path:
         cakey_path = os.path.join(tmp_dir, credential_dict['cakey'])
         cacert_path = os.path.join(tmp_dir, credential_dict['cacert'])
@@ -1514,12 +1579,14 @@ def build_server_key(tmp_dir, ca_cakey_path=None,
     cmd = "%s --generate-privkey > %s" % (certtool, serverkey_path)
     cmd_result = process.run(cmd, ignore_status=True, shell=True)
     if cmd_result.exit_status:
-        raise ConnPrivKeyError(serverkey_path, results_stderr_52lts(cmd_result))
+        raise ConnPrivKeyError(serverkey_path, cmd_result.stderr_text)
 
     # prepare a info file to build servercert and serverkey
     serverinfo_file = open(serverinfo_path, "w")
     serverinfo_file.write("organization = AUTOTEST.VIRT\n")
     serverinfo_file.write("cn = %s\n" % (server_cn))
+    serverinfo_file.write("dns_name = %s\n" % (server_cn))
+    serverinfo_file.write("ip_address = %s\n" % (server_ip))
     serverinfo_file.write("tls_www_server\n")
     serverinfo_file.write("encryption_key\n")
     serverinfo_file.write("signing_key\n")
@@ -1533,11 +1600,11 @@ def build_server_key(tmp_dir, ca_cakey_path=None,
             cakey_path, serverinfo_path, servercert_path))
     CmdResult = process.run(cmd, ignore_status=True)
     if CmdResult.exit_status:
-        raise ConnCertError(serverinfo_path, results_stderr_52lts(CmdResult))
+        raise ConnCertError(serverinfo_path, CmdResult.stderr_text)
 
 
-def build_CA(tmp_dir, cn="AUTOTEST.VIRT", ca_cakey_path=None,
-             certtool="certtool", credential_dict=None):
+def build_CA(tmp_dir, cn="AUTOTEST.VIRT", certtool="certtool",
+             credential_dict=None):
     """
     setup private key and certificate file which are needed to build.
     certificate file for client and server.
@@ -1548,11 +1615,11 @@ def build_CA(tmp_dir, cn="AUTOTEST.VIRT", ca_cakey_path=None,
     (4).make a certificate file with certtool command.
     :param tmp_dir: temp directory to store credentail files in
     :param cn: cn for CA info
-    :param ca_cakey_path: path of CA key file
     :param certtool: cert command
     :param credential_dict: A dict for credential files' names
     """
     # initialize variables
+    ca_cakey_path = credential_dict.get('ca_cakey_path', None)
     if not ca_cakey_path:
         cakey_path = os.path.join(tmp_dir, credential_dict['cakey'])
     else:
@@ -1567,7 +1634,7 @@ def build_CA(tmp_dir, cn="AUTOTEST.VIRT", ca_cakey_path=None,
         cmd = "%s --generate-privkey > %s " % (certtool, cakey_path)
         cmd_result = process.run(cmd, ignore_status=True, timeout=10, shell=True)
         if cmd_result.exit_status:
-            raise ConnPrivKeyError(cakey_path, results_stderr_52lts(cmd_result))
+            raise ConnPrivKeyError(cakey_path, cmd_result.stderr_text)
     # prepare a info file to build certificate file
     cainfo_file = open(cainfo_path, "w")
     cainfo_file.write("cn = %s\n" % cn)
@@ -1581,7 +1648,7 @@ def build_CA(tmp_dir, cn="AUTOTEST.VIRT", ca_cakey_path=None,
            (certtool, cakey_path, cainfo_path, cacert_path))
     CmdResult = process.run(cmd, ignore_status=True)
     if CmdResult.exit_status:
-        raise ConnCertError(cainfo_path, results_stderr_52lts(CmdResult))
+        raise ConnCertError(cainfo_path, CmdResult.stderr_text)
 
 
 class UNIXConnection(ConnectionBase):
@@ -1597,7 +1664,8 @@ class UNIXConnection(ConnectionBase):
                  'client_ip', 'client_user', 'client_pwd',
                  'client_libvirtdconf', 'restart_libvirtd',
                  'client_saslconf', 'client_hosts', 'sasl_type', 'libvirt_ver',
-                 'sasl_allowed_username_list', 'client_libvirtd_socket')
+                 'sasl_allowed_username_list', 'client_libvirtd_socket',
+                 'traditional_mode')
 
     def __init__(self, *args, **dargs):
         """
@@ -1635,6 +1703,8 @@ class UNIXConnection(ConnectionBase):
             'restart_libvirtd', 'yes')
         init_dict['sasl_allowed_username_list'] = init_dict.get(
             'sasl_allowed_username_list', '["root/admin" ]')
+        init_dict['traditional_mode'] = init_dict.get(
+            'traditional_mode', 'no')
 
         super(UNIXConnection, self).__init__(init_dict)
 
@@ -1682,6 +1752,8 @@ class UNIXConnection(ConnectionBase):
         (1).Delete remote file.
         (2).Restart libvirtd on server.
         """
+        traditional_mode = self.traditional_mode
+
         del self.client_libvirtdconf
         del self.client_saslconf
         del self.client_hosts
@@ -1691,10 +1763,18 @@ class UNIXConnection(ConnectionBase):
         try:
             libvirtd_service = utils_libvirtd.Libvirtd(session=client_session)
             if self.libvirt_ver:
-                process.run("systemctl daemon-reload")
-                process.run("systemctl stop libvirtd.socket")
+                # For traditional mode, need unmask libvirtd*.socket
+                if traditional_mode == 'yes':
+                    process.run("systemctl unmask libvirtd.socket", shell=True)
+                    process.run("systemctl unmask libvirtd-admin.socket", shell=True)
+                    process.run("systemctl unmask libvirtd-ro.socket", shell=True)
+                    process.run("systemctl unmask libvirtd-tcp.socket", shell=True)
+                    process.run("systemctl unmask libvirtd-tls.socket", shell=True)
+                else:
+                    process.run("systemctl daemon-reload", shell=True)
+                    process.run("systemctl stop libvirtd.socket", shell=True)
                 libvirtd_service.stop()
-                process.run("systemctl start libvirtd.socket")
+                process.run("systemctl start libvirtd.socket", shell=True)
                 libvirtd_service.start()
             else:
                 libvirtd_service.restart()
@@ -1724,6 +1804,7 @@ class UNIXConnection(ConnectionBase):
         restart_libvirtd = self.restart_libvirtd
         client_session = self.client_session
         sasl_allowed_username_list = self.sasl_allowed_username_list
+        traditional_mode = self.traditional_mode
 
         # edit the /etc/libvirt/libvirtd.conf to add auth_unix_ro arg
         if auth_unix_ro:
@@ -1773,7 +1854,7 @@ class UNIXConnection(ConnectionBase):
 
         # edit the /etc/libvirt/libvirtd.conf to add unix_sock_rw_perms arg
         if unix_sock_rw_perms:
-            if self.libvirt_ver:
+            if self.libvirt_ver and traditional_mode == 'no':
                 pattern_to_repl = {r".*SocketMode\s*=.*":
                                    'SocketMode=%s' % unix_sock_rw_perms}
                 self.client_libvirtd_socket.sub_else_add(pattern_to_repl)
@@ -1791,7 +1872,7 @@ class UNIXConnection(ConnectionBase):
             keytab = "keytab: /etc/libvirt/krb5.tab"
             sasldb = ""
             remote_runner = remote.RemoteRunner(session=client_session)
-            hostname = remote_runner.run('hostname', ignore_status=True).stdout.strip()
+            hostname = remote_runner.run('hostname', ignore_status=True).stdout_text.strip()
             pattern_to_repl = {r".*127.0.0.1\s*.*":
                                "127.0.0.1    %s localhost localhost.localdomain "
                                "localhost4 localhost4.localdomain6" % hostname,
@@ -1818,10 +1899,25 @@ class UNIXConnection(ConnectionBase):
                 libvirtd_service = utils_libvirtd.Libvirtd(
                     session=client_session)
                 if self.libvirt_ver:
-                    process.run("systemctl stop libvirtd.socket")
-                    libvirtd_service.stop()
-                    process.run("systemctl daemon-reload")
-                    process.run("systemctl start libvirtd.socket")
+                    # For traditional mode, need mask libvirtd*.socket
+                    if traditional_mode == 'yes':
+                        process.run("systemctl stop libvirtd.socket", shell=True)
+                        process.run("systemctl stop libvirtd-admin.socket", shell=True)
+                        process.run("systemctl stop libvirtd-ro.socket", shell=True)
+                        process.run("systemctl stop libvirtd-tcp.socket", shell=True)
+                        process.run("systemctl stop libvirtd-tls.socket", shell=True)
+                        libvirtd_service.stop()
+                        process.run("systemctl mask libvirtd.socket", shell=True)
+                        process.run("systemctl mask libvirtd-admin.socket", shell=True)
+                        process.run("systemctl mask libvirtd-ro.socket", shell=True)
+                        process.run("systemctl mask libvirtd-tcp.socket", shell=True)
+                        process.run("systemctl mask libvirtd-tls.socket", shell=True)
+                        process.run("systemctl daemon-reload", shell=True)
+                    else:
+                        process.run("systemctl stop libvirtd.socket", shell=True)
+                        libvirtd_service.stop()
+                        process.run("systemctl daemon-reload", shell=True)
+                        process.run("systemctl start libvirtd.socket", shell=True)
                     libvirtd_service.start()
                 else:
                     libvirtd_service.restart()
