@@ -33,7 +33,6 @@ from virttest import utils_misc
 from virttest import qemu_monitor
 from virttest.qemu_devices import qdevices
 from virttest.staging import utils_memory
-from virttest.compat_52lts import decode_to_text
 
 
 def guest_active(vm):
@@ -558,9 +557,14 @@ class MemoryHotplugTest(MemoryBaseTest):
         :param dev: Qdevice object.
         """
         error_context.context("Update VM object after hotplug memory")
-        attrs = dev.__attributes__[:]
-        params = self.params.copy_from_keys(attrs)
         dev_type, name = dev.get_qid().split('-')
+        if isinstance(dev, qdevices.Memory):
+            backend = self.params.object_params(name).get("backend_mem",
+                                                          "memory-backend-ram")
+            attrs = dev.__attributes__[backend][:]
+        else:
+            attrs = dev.__attributes__[:]
+        params = self.params.copy_from_keys(attrs)
         for attr in attrs:
             val = dev.get_param(attr)
             if val:
