@@ -14,8 +14,8 @@ import uuid
 
 from avocado.utils import path
 from avocado.utils import process
+from avocado.utils.astring import to_text
 from avocado.core import exceptions
-from virttest.compat_52lts import results_stdout_52lts, results_stderr_52lts, decode_to_text
 
 from virttest.utils_test import libvirt
 from virttest.libvirt_xml import vm_xml
@@ -143,9 +143,8 @@ class Target(object):
         """
         Target dispatcher.
         """
-        opts_func = getattr(self, "_get_%s_options" % self.target)
         self.params = params
-        self.output_method = self.params.get('output_method', 'rhev')
+        self.output_method = self.params.get('output_method', 'rhv')
         self.input_mode = self.params.get('input_mode')
         self.esxi_host = self.params.get(
             'esxi_host', self.params.get('esx_ip'))
@@ -162,9 +161,7 @@ class Target(object):
         self.vm_name = self.params.get('main_vm')
         self.bridge = self.params.get('bridge')
         self.network = self.params.get('network')
-        self.storage = self.params.get('storage')
-        self.storage_name = self.params.get('storage_name')
-        self.format = self.params.get('output_format', 'raw')
+        self.of_format = self.params.get('of_format', 'raw')
         self.input_file = self.params.get('input_file')
         self.new_name = self.params.get('new_name')
         self.username = self.params.get('username', 'root')
@@ -339,7 +336,7 @@ class Target(object):
         elif self.input_transport is None:
             self.net_vm_opts += " %s" % self._vmx_filename_fullpath
 
-        options = opts_func() + _compose_input_transport_options()
+        options = self.get_target_options() + _compose_input_transport_options()
 
         if self.new_name:
             options += ' -on %s' % self.new_name
@@ -355,47 +352,99 @@ class Target(object):
             options = re.sub(r'-ic .*? ', '', options)
         return options
 
+    def _get_os_directory(self):
+        """
+        Prepare a local os directory for v2v conversion.
+
+        Correspond to '-os DIRECTORY'.
+        """
+        os_directory = self.params.get('os_directory')
+
+        if not os_directory:
+            os_directory = os.path.join(
+                data_dir.get_tmp_dir(), 'v2v_os_directory')
+            if not os.path.exists(os_directory):
+                os.makedirs(os_directory)
+        # Pass the json directory to testcase for checking
+        self.params.get('params').update({'os_directory': os_directory})
+
+        logging.debug('The os directory(-os DIRECTORY) is %s.', os_directory)
+        return os_directory
+
     def _get_libvirt_options(self):
         """
-        Return command options.
-        """
-        options = " -ic %s -os %s -of %s" % (self.uri,
-                                             self.storage,
-                                             self.format)
-        options = options + self.net_vm_opts
+        Construct output options for -o libvirt
 
-        return options
-
-    def _get_libvirtxml_options(self):
+        'os_pool' corresponds to '-os POOL'.
         """
-        Return command options.
-        """
-        options = " -os %s" % self.storage
-        options = options + self.net_vm_opts
+        os_pool = self.params.get('os_pool')
+        options = " -os %s" % os_pool
 
         return options
 
     def _get_ovirt_options(self):
         """
-        Return command options.
+        Construct output options for -o ovirt
+
+        'os_storage' corresponds to '-o rhv -os [esd:/path|/path'.
+        'os_storage_name' corresponds to '-o rhv -os STORAGE'.
+        'rhv_upload_opts' includes all '-oo xxx' options.
         """
-        options = " -ic %s -o %s -os %s -of %s" % (
-            self.uri,
-            self.output_method.replace('_', '-'),
-            self.storage if self.output_method != "rhv_upload" else self.storage_name,
-            self.format)
-        options = options + self.net_vm_opts
+        os_storage = self.params.get('os_storage')
+        os_storage_name = self.params.get('os_storage_name')
+        rhv_upload_opts = self.params.get('rhv_upload_opts')
+        output_method = self.output_method
+        options = " -os %s" % (os_storage if output_method != "rhv_upload" else os_storage_name)
+        if rhv_upload_opts:
+            options += ' %s' % rhv_upload_opts
 
         return options
 
     def _get_local_options(self):
+        """
+        Construct output options for -o local
+        """
+        os_directory = self._get_os_directory()
+        options = " -os %s" % os_directory
+
+        return options
+
+    def _get_null_options(self):
+        """
+        Construct output options for -o null
+        """
+        return ''
+
+    def _get_json_options(self):
+        """
+        Construct output options for -o json
+
+        'oo_json_disk_pattern' corresponds to '-o json [-oo json-disks-pattern=PATTERN]'
+        """
+        oo_json_disk_pattern = self.params.get('oo_json_disk_pattern')
+        os_directory = self._get_os_directory()
+
+        options = " -os %s" % os_directory
+        if oo_json_disk_pattern:
+            options += " -oo json-disks-pattern=%s" % oo_json_disk_pattern
+
+        return options
+
+    def get_target_options(self):
         """
         Return command options.
         """
-        options = " -ic %s -o local -os %s -of %s" % (self.uri,
-                                                      self.storage,
-                                                      self.format)
-        options = options + self.net_vm_opts
+        uri = self.uri
+        target = self.target
+        o_fmt = self.of_format
+        _get_target_specific_options = getattr(
+            self, "_get_%s_options" % self.target)
+
+        if target == 'ovirt':
+            target = self.output_method.replace('_', '-')
+
+        options = " -ic %s -o %s -of %s" % (uri, target, o_fmt)
+        options += _get_target_specific_options() + self.net_vm_opts
 
         return options
 
@@ -455,6 +504,9 @@ class VMCheck(object):
             raise ValueError("Doesn't support %s target now" % self.target)
 
     def create_session(self, timeout=480):
+        if self.session:
+            logging.debug('vm session %s exists', self.session)
+            return
         self.session = self.vm.wait_for_login(nic_index=self.nic_index,
                                               timeout=timeout,
                                               username=self.username,
@@ -468,7 +520,13 @@ class VMCheck(object):
         if self.session:
             logging.debug('vm session %s is closing', self.session)
             self.session.close()
+            self.session = None
 
+        # If VMChecker is instantiated before import_vm_to_ovirt and
+        # the VMChecker.run is skiped, self.vm.instance will be NULL.
+        # The update_instance should be ran before cleaning up.
+        if hasattr(self.vm, 'update_instance'):
+            self.vm.update_instance()
         if self.vm.instance and self.vm.is_alive():
             self.vm.destroy(gracefully=False)
             time.sleep(5)
@@ -1129,6 +1187,8 @@ def v2v_cmd(params, auto_clean=True, cmd_only=False):
             # in the case, vm_name is same as nfs directory name
             if input_mode == 'vmx':
                 params['_nfspath'] = vm_name
+        # Pass it to testcase to do subsequent checking
+        global_params.update({'vm_disk_count': params['_disk_count']})
 
     def _v2v_post_cmd():
         """
@@ -1161,7 +1221,6 @@ def v2v_cmd(params, auto_clean=True, cmd_only=False):
     # the value is bigger than the timeout value in CI, so when some timeout
     # really happens, CI will still interrupt the v2v process.
     v2v_cmd_timeout = params.get('v2v_cmd_timeout', 18000)
-    rhv_upload_opts = params.get('rhv_upload_opts')
     # username and password of remote hypervisor server
     username = params.get('username', 'root')
     password = params.get('password')
@@ -1181,17 +1240,15 @@ def v2v_cmd(params, auto_clean=True, cmd_only=False):
         vpx_dc = None
     uri = uri_obj.get_uri(hostname, vpx_dc, esxi_host)
 
-    # Pre-process for v2v
-    _v2v_pre_cmd()
-
-    target_obj = Target(target, uri)
     try:
+        # Pre-process for v2v
+        _v2v_pre_cmd()
+
+        target_obj = Target(target, uri)
         # Return virt-v2v command line options based on 'target' and
         # 'hypervisor'
         options = target_obj.get_cmd_options(params)
 
-        if rhv_upload_opts:
-            options = options + ' ' + rhv_upload_opts
         if opts_extra:
             options = options + ' ' + opts_extra
         # Add -oo rhv-disk-uuid if '--no-copy' exists
@@ -1212,22 +1269,21 @@ def v2v_cmd(params, auto_clean=True, cmd_only=False):
             cmd_result = process.run(cmd, timeout=v2v_cmd_timeout,
                                      verbose=True, ignore_status=True)
     finally:
-        if auto_clean:
-            target_obj.cleanup()
-        else:
-            # Save it into global params and release it by users
-            v2v_dirty_resources = global_params.get('v2v_dirty_resources', [])
-            v2v_dirty_resources.append(target_obj)
-            global_params.update({'v2v_dirty_resources': v2v_dirty_resources})
+        # Save it into global params and release it by users
+        v2v_dirty_resources = global_params.get('v2v_dirty_resources', [])
+        global_params.update({'v2v_dirty_resources': v2v_dirty_resources})
+        if 'target_obj' in locals():
+            if auto_clean:
+                target_obj.cleanup()
+            else:
+                v2v_dirty_resources.append(target_obj)
         # Post-process for v2v
         _v2v_post_cmd()
 
     if cmd_only:
         return cmd
-
-    cmd_result.stdout = results_stdout_52lts(cmd_result)
-    cmd_result.stderr = results_stderr_52lts(cmd_result)
-
+    cmd_result.stdout = cmd_result.stdout_text
+    cmd_result.stderr = cmd_result.stderr_text
     return cmd_result
 
 
@@ -1314,6 +1370,9 @@ def import_vm_to_ovirt(params, address_cache, timeout=600):
                 v2v_cmd)
     except Exception as e:
         logging.error("Start %s failed: %s", vm.name, e)
+        vm.delete()
+        if output_method != 'rhv_upload':
+            vm.delete_from_export_domain(export_name)
         return False
     return True
 
@@ -1373,15 +1432,11 @@ def check_exit_status(result, expect_error=False, error_flag='strict'):
     if not expect_error:
         if result.exit_status != 0:
             raise exceptions.TestFail(
-                decode_to_text(
-                    result.stderr,
-                    errors=error_flag))
+                to_text(result.stderr, errors=error_flag))
         else:
             logging.debug(
                 "Command output:\n%s",
-                decode_to_text(
-                    result.stdout,
-                    errors=error_flag).strip())
+                to_text(result.stdout, errors=error_flag).strip())
     elif expect_error and result.exit_status == 0:
         raise exceptions.TestFail("Run '%s' expect fail, but run "
                                   "successfully." % result.command)
@@ -1709,8 +1764,7 @@ def v2v_supported_option(opt_str):
     """
     cmd = 'virt-v2v --help'
     result = process.run(cmd, verbose=True, ignore_status=True)
-    result.stdout = results_stdout_52lts(result)
-    if re.search(r'%s' % opt_str, result.stdout):
+    if re.search(r'%s' % opt_str, result.stdout_text):
         return True
     return False
 
